/*ZAGALL.JS LOGIC*************************************************/

// Copyright: Copyright (c) 2006, 2009, Gannett Inc. All rights reserved. 

/*********
* Config *
*********/
var zagEnabled		= 0; // use zagito form?
var ZAGITOEnabled	= 1; // do anything at all?
if (!self.zagitoPrefix)
	zagitoPrefix	= 'http://content.usatoday.com/registration/zagito5';
var throttle		= 100;
// var gcion_rdb_cookie	= "RDB";
var gcion_site_code	= "reg.usatoday.com";
var gcion_url		= "http://usata1.gcion.com/";
var gcion_version	= "1.0.2r-USAT2007516";

/* ==================================================================== */
/* Defines the GCION global namespace					*/
/* ==================================================================== */

var GCION = window.GCION || {};

/// <summary>
/// Ensure named namespace exists in GCION object
/// </summary>
/// <param name="nameSpace">string representing required namespace.</param>
/// <returns>the [new?] namespace object.</returns>
if (!GCION.namespace) 
	GCION.namespace= function(nameSpace) {
		if (!nameSpace || !nameSpace.length) return null;
		var currentNamespace = GCION;
		var names= nameSpace.split('.');
		for (var j= 0; j < names.length; j++) 
			currentNamespace= currentNamespace[names[j]]= currentNamespace[names[j]] || {};
		return currentNamespace;
	};

/* ==================================================================== */
/* Required namespaces							*/
/* ==================================================================== */
GCION.namespace("Data");
GCION.namespace("Callbacks");
GCION.namespace("Cookies");
GCION.namespace("Sites");
GCION.namespace("Utils");

/* ==================================================================== */
/* Forward comaptability						*/
/* ==================================================================== */
GDN= {UR: {UserData: null}};

/* ==================================================================== */
/* GCION.Data.GCION							*/
/* ==================================================================== */
/// <summary>
/// Provides a class that defines the data structure of a GCION cookie. 
/// </summary>
GCION.Data.GCION = function() {};
GCION.Data.GCION.prototype = {
	// GCION data
	GcionId: null,
	CookieVersion: null,
	CreationDate: null,
	RegistrationStatus: null,
	Sessions: null,
	
	// ZAGITO data
	ZipCode: null,
	Gender: null,
	Occupation: null,
	Industry: null,
	CompanySize: null,
	YearOfBirth: null,
	Country: null,
	OriginatingSite: null,
	Email: null
};


/* ==================================================================== */
/* GCION.Callbacks							*/
/* ==================================================================== */

// HACK: try to emulate callback behavior using interval timer and cookie watching
// after the GCIONID cookie value changes, run fn();
GCION.Callbacks.SetCallback= function(fn) {
	var interval= null;
	var old= GDN.UR.UserData ?GDN.UR.UserData :null;
	var watchGCIONID= function() {
		if (!self.GCION) { /* page is unloading */
			clearInterval(interval);
		} else {
			if (GDN.UR.UserData && old != GDN.UR.UserData) {
				clearInterval(interval);
				fn(GDN.UR.UserData);
			}
		}
	}
	interval= setInterval(watchGCIONID, 500);
};


// Set or Get GCION data then run fnName();
GCION.Callbacks.ScheduleZag= function(fn, willSet) {
	var setData= function(fnName) { // post data to GCION then run fnName()
		GCION.Sites.USAT.ConvertToGCION();
		GCION.Callbacks.SetCallback(fnName);
	};
	var getData= function(fnName) { // get data from GCION then run fnName()
		GCION.Utils.Include.Once(GCION.Utils.Data.GetGcionUrl("q=3&NoCookie=1"));
		GCION.Callbacks.SetCallback(fnName);
	}
	var interval= null;
	function waitForIE() {
		if (!self.ZAGITOEnabled) { /* system turned off or page is unloading */
			clearInterval(interval);
		} else {
			if (self.GCION) { // have GCION, assume it's populated
				clearInterval(interval);
				if (willSet) {
					setData(fn);
				} else {
					getData(fn);
				}
			}
		}
	}
	if (self.GCION) {
		if (willSet) {
			setData(fn);
		} else {
			getData(fn);
		}
	} else {
		interval= setInterval(waitForIE, 50);
	}
}


/* ==================================================================== */
/* GCION.Cookies							*/
/* ==================================================================== */
/// <summary>
/// use and manipulate arbitrary cookies
/// </summary>
GCION.Cookies.Cookie = {
	/// <summary>
	/// Gets the value stored in the specified cookie.
	/// When domain is ambiguous, gets the longest value
	/// (which, presumably, contains the most information,
	/// and is thus the most pertinent).
	/// </summary>
	/// <param name="name">The name of the cookie.</param>
	Get : function(name) {
		var values= (' '+document.cookie).match(new RegExp(' '+name+'=[^;]*', 'g')) || [];
		var valLen= 0;	// length of best match, so far
		var result= null;
		for (var j= 0; j < values.length; j++)
			if (values[j].length > valLen) {
				valLen= values[j].length;
			result= unescape(values[j].substring(2+name.length));
		}
		return result;
	},

	/// <summary>
	/// Sets a value that is stored in the specified cookie.
	/// </summary>
	/// <param name="name">The name of the cookie.</param>
	/// <param name="value">The value to store in the cookie.</param>
	/// <param name="expires">The expiration date of the cookie.</param>
	/// <param name="path">The path to the cookie.</param>
	/// <param name="domain">The domain name for the cookie.</param>
	/// <param name="secure">A value indicating whether the cookie is secure.</param>
	Set : function(name, value, expires, path, domain, secure) {
		if (expires) {
			var expirationDate= new Date(new Date().getTime() + expires * 1000 * 60 * 60 * 24);
			expires= expirationDate.toGMTString();
		}
		document.cookie = name+'='      + value +
			(expires ? ';expires='  + expires  : ''        ) +
			(path    ? ';path='     + path     : ';path=/' ) +
			(domain  ? ';domain='   + domain   : ';domain='+GCION.Utils.Data.GetDomainName()) +
			(secure  ? ';secure'               : ''        );
	},
	
	/// <summary>
	/// Removes the specified cookie.
	/// </summary>
	/// <param name="name">The name of the cookie.</param>
	/// <param name="path">The path to the cookie.</param>
	/// <param name="domain">The domain name for the cookie.</param>
	Remove : function(name, path, domain) {
		if (this.Exists(name)) 
			document.cookie = name+'='   +
				(path   ? ';path='   + path   : '/') +
				(domain ? ';domain=' + domain : ';domain='+GCION.Utils.Data.GetDomainName()) +
				';expires=Thu, 01-Jan-1970 00:00:01 GMT';
		
	},

	/// <summary>
	/// Gets a value indicating if the cookie exists.
	/// </summary>
	/// <param name="cookieName">The name of the cookie.</param>
	Exists : function(cookieName) {
		var values= (' '+document.cookie).match(new RegExp(' '+name+'=[^;]*', 'g')) || [];
		return values.length > 0;
	}
};


/* ==================================================================== */
/* GCION.Data.RDB (obsolete)						*/
/* ==================================================================== */

/*
/// <summary>
/// Obsolete
/// </summary>
GCION.Data.RDB = function() {};
GCION.Data.RDB.prototype = {
	Publisher: null,
	Version: null,
	ZipCode: null,
	ZipCodeExt: null,
	Country: null,
	State: null,
	Gender: null,
	Subscriber: null,
	IncomeLow: null,
	IncomeHigh: null,
	AgeLow: null,
	AgeHigh: null,
	Trait1: null,
	Trait2: null,
	Trait3: null,
	Trait4: null,
	Trait5: null,
	Trait6: null,
	Trait7: null,
	Trait8: null
};
/* ==================================================================== */
/* GCION.Cookies.RDB (obsolete)						*/
/* ==================================================================== */
/*
/// <summary>
/// for handling RDB cookies. 
/// </summary>
GCION.Cookies.RDB = {
	/// <summary>
	/// Gets a RDB data object filled with data from the specified cookie.
	/// </summary>
	/// <param name="cookieName">The name of the cookie.</param>
	GetData : function(cookieName) {			 
		// get the cookie
		var cookieData = GCION.Cookies.Cookie.Get(cookieName);
			 
		// initialize RDB data object
		var cookie = new GCION.Data.RDB();

		// set properties values
		cookie.Publisher = this.ToInt(cookieData.substring(0, 2));
		cookie.Version = this.ToInt(cookieData.substring(2, 4));
		cookie.ZipCode = this.ToInt(cookieData.substring(4, 10));
		cookie.ZipCodeExt = this.ToInt(cookieData.substring(10, 14));
		cookie.Country = this.GetString(cookieData.substring(14, 18));
		cookie.Gender = this.ToInt(cookieData.substring(18, 20));
		cookie.Subscriber = this.ToInt(cookieData.substring(20, 22));
		cookie.IncomeLow = this.ToInt(cookieData.substring(22, 24));
		cookie.IncomeHigh = this.ToInt(cookieData.substring(24, 26));
		cookie.AgeLow = this.ToInt(cookieData.substring(26, 28));
		cookie.AgeHigh = this.ToInt(cookieData.substring(28, 30));
		cookie.Trait1 = this.ToInt(cookieData.substring(30, 32));
		cookie.Trait2 = this.ToInt(cookieData.substring(32, 34));
		cookie.Trait3 = this.ToInt(cookieData.substring(34, 36));
		cookie.Trait4 = this.ToInt(cookieData.substring(36, 38));
		cookie.Trait5 = this.ToInt(cookieData.substring(38, 40));
		cookie.Trait6 = this.ToInt(cookieData.substring(40, 42));
		cookie.Trait7 = this.ToInt(cookieData.substring(42, 44));
		cookie.Trait8 = this.ToInt(cookieData.substring(44, 46));
										
		return cookie;
	},
	
	/// <summary>
	/// Converts a hexadecimal value to a integer value.
	/// </summary>
	/// <param name="hex">The hexadecimal value to convert.</param>
	ToInt : function(hex) {
		return parseInt(hex, 16);
	},
	
	
	/// <summary>
	/// Converts the specified integer to a character.
	/// </summary>
	/// <param name="chr">The integer value to convert.</param>
	ToChar : function(integer) {
		return String.fromCharCode(integer);
	},
	
	/// <summary>
	/// Gets a string for the specified hexadecimal value.
	/// </summary>
	/// <param name="integer">The hexadecimal value to get as a string.</param>
	GetString : function(hex) {
		var str = "";
		for (var i = 0; i < hex.length; i+=2)
			if (i != hex.length) {
				var value = hex.charAt(i) + hex.charAt(i + 1);
				str += this.ToChar(this.ToInt(value));
			}
		return str;
	}
};

/* ==================================================================== */
/* GCION.Utils.Data							*/
/* ==================================================================== */

/// <summary>
/// data handling utilities. 
/// </summary>
GCION.Utils.Data = {	
	/// <summary>
	/// Gets a value indicating if the specified object is or was null or empty.
	/// </summary>
	/// <param name="object">The object we are concerned with </param>
	IsNullOrEmpty : function(object) {
		if (object == null || (object == '' && 'number' != typeof object) || object.length == 0 || object == "null" || object == "undefined")
			return true;
		else
			return false;
	},
	
	/// <summary>
	/// Gets the top level domain name for the current site.
	/// </summary>
	GetDomainName : function() {
		var domain = window.location.host;
		var match = /([\w-]+)+\.[a-zA-Z]{2,3}$/i.exec(domain);
		return match ?"." + match[0] :domain;
	},
	
	/// <summary>
	/// Gets the version number of the USAT GCION library.
	/// </summary>
	GetVersion : function() {
		return gcion_version;
	},
	
	/// <summary>
	/// Gets the year of birth for the specified age.
	/// </summary>
	/// <param name="age">The age of the user.</param>
	GetYob : function(age) {
		var today = new Date();				 
		return today.getFullYear() - age;
	},
	
	/// <summary>
	/// Gets the GCION URL and appends the specified query string parameters.
	/// </summary>
	/// <param name="paramsString">A list of query string parameters to append.</param>
	GetGcionUrl : function(paramsString) {
		// define the GCION URL
		var sep= gcion_url.match(/\/$/ ?'' :'/');
		var url= gcion_url + sep + 'gcion.ashx';
		if (!this.IsNullOrEmpty(paramsString)) // append query character to URL if a query string was passed
			url += "?" + paramsString + "&Path=" + escape(this.GetDomainName())+"&CacheDefeat="+new Date().getTime();
		return url;
	}
};

/* ==================================================================== */
/* GCION.Utils.Include							*/
/* ==================================================================== */

// set global variable used by Include object
var gcion_included_files= [];

/// <summary>
/// Provides an object containing script include utilities. 
/// </summary>
GCION.Utils.Include = {	
	/// <summary>
	/// Appends a JavaScript include to the DOM.
	/// </summary>
	/// <param name="scriptFilename">The name of the JavaScript file to include.</param>
	/// <param name="identifier">The unique identifier for the JavaScript file to include.</param>
	ToDom : function(scriptFilename, identifier) {
		// define DOM elements
		var htmlDoc = document.getElementsByTagName('head').item(0);
		var scriptTag = document.createElement('script');
			
		// set tag attributes
		scriptTag.setAttribute('language', 'javascript');
		scriptTag.setAttribute('type', 'text/javascript');
		scriptTag.setAttribute('src', scriptFilename);
		
		// set identifier if specified
		if (!GCION.Utils.Data.IsNullOrEmpty(identifier))
			scriptTag.setAttribute('id', identifier);
			
		// append tag to DOM
		htmlDoc.appendChild(scriptTag);
	},

	/// <summary>
	/// Dynamically includes a JavaScript file only once per page.
	/// </summary>
	/// <param name="scriptFilename">The name of the JavaScript file to include.</param>
	/// <param name="identifier">The unique identifier for the JavaScript file to include.</param>
	Once : function(scriptFilename, identifier) {
		if (!this.InArray(scriptFilename, gcion_included_files)) {
			gcion_included_files.push(scriptFilename);
			this.ToDom(scriptFilename, identifier);
		}
	},
	
	/// <summary>
	/// Determines if array contains a string
	//  we should have been checking of object had named property
	//  but this allows for backwards compatability and is not overly inefficient
	/// </summary>
	/// <param name="needle">string to look for</param>
	/// <param name="haystack">array or strings to search</param>
	InArray : function(needle, haystack) {
		for (var hay in haystack)
			if (hay == needle) return true;
		return false;
	}
};

/* ==================================================================== */
/* GCION.Sites.USAT							*/
/* ==================================================================== */

/// <summary>
/// Provides an object for handling events for USAT. 
/// </summary>
GCION.Sites.USAT = {
	/// <summary>
	/// Captures ZAGITO/O data from the specified GCION data object.
	/// </summary>
	/// <param name="gcion">A defined GCION data object.</param>
	CaptureZagito : function(gcion) { 
		// set the required query string parameters
		var querystring = "q=2&NoCookie=1&GCIONID=" + gcion.GcionId +
			"&YOB=" + gcion.YearOfBirth +
			"&Gender=" + gcion.Gender +
			"&Country=" + gcion.Country.toLowerCase() +
			"&OriginatingSite=" + escape(gcion_site_code);
			
		// set optional values
		if (!GCION.Utils.Data.IsNullOrEmpty(gcion.ZipCode)) {
			if (gcion.Country.toLowerCase() == "us")
				querystring += "&Zip=" + gcion.ZipCode;
		}
	
		if (!GCION.Utils.Data.IsNullOrEmpty(gcion.Occupation)) querystring += "&Occupation=" + gcion.Occupation;
		if (!GCION.Utils.Data.IsNullOrEmpty(gcion.Industry)) querystring += "&Industry=" + gcion.Industry;
		if (!GCION.Utils.Data.IsNullOrEmpty(gcion.CompanySize)) querystring += "&CompanySize=" + gcion.CompanySize;
			
		// ZAGITO/O the user
		GCION.Utils.Include.Once(GCION.Utils.Data.GetGcionUrl(querystring));
	},

	/// <summary>
	/// Converts a USAT cookie to a GCION cookie.
	/// </summary>
	ConvertToGCION : function() {
		// get existing ZAGITO/O data from RDB cookie
/*		if (GCION.Cookies.Cookie.Exists(gcion_rdb_cookie)) {
			// GCION.Utils.Include.Once(GCION.Utils.Data.GetGcionUrl("q=3&NoCookie=1"));
			// setTimeout("GCION.Sites.USAT.GetZagito()", 500);
			this.GetZagito(new GCION.Data.GCION());
		}
		else*/ if (GCION.Cookies.Cookie.Exists('zagCookie')) {

			// get the USAT cookie
			var usatCookie = GCION.Cookies.Cookie.Get('zagCookie');
		
			// only get data from version 3 of USAT ZAGITO cookie
			if (usatCookie.charAt(0) == 3) {
				// GCION.Utils.Include.Once(GCION.Utils.Data.GetGcionUrl("q=3&NoCookie=1"));
				// setTimeout("GCION.Sites.USAT.GetZagito()", 500); 
				this.GetZagito(new GCION.Data.GCION());
			}
		}
	},

/*
	/// <summary>
	/// Gets a GCION cookie object filled with USAT ZAGITO data.
	/// </summary>
	GetZagito : function(cookie) {
		if (GCION.Cookies.Cookie.Exists(gcion_rdb_cookie) && GCION.Cookies.Cookie.Exists('zagCookie')) {		
			// get the RDB cookie
			var rdbCookie = GCION.Cookies.RDB.GetData(gcion_rdb_cookie);
			
			// set properties
			cookie.Gender= 3-rdbCookie.Gender;

			cookie.Country = rdbCookie.Country.toString().toLowerCase();
			cookie.ZipCode = rdbCookie.ZipCode;
			cookie.YearOfBirth = GCION.Utils.Data.GetYob((rdbCookie.AgeLow + rdbCookie.AgeHigh) / 2);
			
			// override with usat cookie
			// (required -- usat cookie has GCIONID)
			// then capture ZAGITO/O data
			this.GetZagito(cookie);
		}
	},
*/

	/* short property names -> long property names */
	PropName : {
		cou: 'Country',
		fem: 'Gender',
		gci: 'GcionId',
		gdt: '',
		ind: 'Industry',
		job: 'Occupation',
		sav: '',
		sit: '',
		siz: 'CompanySize',
		yob: 'YearOfBirth',
		zip: 'ZipCode'
	},
	
	/* names whose values need to be encoded as names */
	NameName : { 
		cou: 1,
		gci: 1,
		key: 1,
		sit: 1
	},
	
	/// <summary>
	/// Gets a GCION cookie object filled with USAT ZAITO data.
	/// </summary>
	GetZagito : function(cookie) {
		if (GCION.Cookies.Cookie.Exists('zagCookie')) {
			// get the USAT cookie
			var usatCookie = this.ZagitoObj();

			// set properties
			for (var name in usatCookie)
				if (this.PropName[name])
					switch (name) {
						case 'fem':
							cookie.Gender= 2-usatCookie[name];
							break;
							
						default:
							cookie[this.PropName[name]]= usatCookie[name];
					}
				
			// capture ZAGITO/O data
			if (!GCION.Utils.Data.IsNullOrEmpty(cookie))
				GCION.Sites.USAT.CaptureZagito(cookie);
		}
	},

	/// <summary>
	/// Parses a USAT cookie and returns its contents as a name/value pair array.
	/// </summary>
	/// <param name="zagCookie">The contents of the USAT ZAGITO/O cookie.</param>
	ParseZagito : function(zagCookie) {
		zagCookie+=""
		var r = new Object();
		r.version = parseInt(zagCookie);
		if (isNaN(r.version)) return {version: 2};
		var nvps = zagCookie.split('n');
		
		for (var j= 0; j < nvps.length; j++) {
			var nv = nvps[j].split('v');
			if (2 == nv.length) {
				var nam = this.DecodeName(nv[0]);
				var val = this.NameName[nam] ? this.DecodeName(nv[1]) : this.DecodeNumber(nv[1]);
				r[nam] = val;
			}
		}
	
		return r;
	},

	ZagitoObj: function() {
		return this.ParseZagito(GCION.Cookies.Cookie.Get('zagCookie'));
	},
	
	///<summary>
	///returns cookie value
	///</summary>
	EncodeZagito : function(obj) {
		var r = obj.version+' ';
		for (var nm in obj) {
			if (3 == nm.length && !GCION.Utils.Data.IsNullOrEmpty(obj[nm])) {
				var val= this.NameName[nm] ?this.EncodeName(obj[nm]) :this.EncodeNumber(obj[nm]);
				r+='n'+this.EncodeName(nm)+'v'+val
			}
		}
		return r;
	},
	
	///<summary>
	///Sets zagCookie
	///<param name="obj">The zagito cookie object to be saved</param>
	SetZagito : function(obj) {
		GCION.Cookies.Cookie.Set('zagCookie', this.EncodeZagito(obj), 3650, '/', '.usatoday.com');
	},

	/// <summary>
	/// Converts an integer value to a hexadecimal value.
	/// </summary>
	/// <param name="integer">The integer value to convert.</param>
	EncodeNumber : function(integer) {
		if (integer < 10) return integer;
		var result = "";
		for (var result = ""; integer; integer>>>=4)
			result = "0123456789abcdef".charAt(integer&0xf) + result;
		return result;
	},

	/// <summary>
	/// Encode sequence of characters as sequence of hexadecimal pairs
	/// </summary>
	/// <param name="name">The ascii string to encode as hex.</param>
	EncodeName : function(name) {
		var result = "";
		for (var i = 0; i < name.length; i++)
			result += this.EncodeNumber(name.charCodeAt(i));
		return result;
	},

	/// <summary>
	/// Decodes a number from its hexadecimal format.
	/// </summary>
	/// <param name="number">The number to decode.</param>
	DecodeNumber : function(number) {
	 return parseInt(number, 16);
	},

	/// <summary>
	/// Decodes a name from its hexadecimal format.
	/// </summary>
	/// <param name="name">The name to decode.</param>
	DecodeName : function(name) { 
		var r = '';
		for (var j= 0; j <name.length; j+=2)
			r+= String.fromCharCode(this.DecodeNumber(name.substring(j, j+2)));
		return r;
	}
};

/*******************
* zagito utilities *
*******************/

function nowDtNum(y,m,d) { /* pack today's date */
	var now= new Date();
	var yr= now.getFullYear();
	yr+= yr < 200 ?1900 :0; /* for broken browser implementations */
	yr+= yr < 1970 ?100 :0; /* for broken browser implementations */
	var mn= now.getMonth();
	var dt= now.getDate()-1;
	return ((yr-2000)*12+mn)*31+dt;
}
/*****************
* zagito support *
*****************/
var zagito= '-1';
function gci2Zagito(gcionidObject) {
	if (gcionidObject) { 
		gcionidObject.adr= null;
		var zagito= GCION.Sites.USAT.ZagitoObj();
		if (gcionidObject.gcionid) zagito.gci= gcionidObject.gcionid;
 		if (!GCION.Utils.Data.IsNullOrEmpty(gcionidObject.zip)) {
 			var status='GCI0';
 			zagito.version= 3;
			for (var p in gcionidObject)
				if (GCION.Utils.Data.IsNullOrEmpty(zagito[p]) && 3 == p.length && (status='GCI' /*not a test*/))
					if ('gen' == p)
						zagito['fem']= 2-gcionidObject[p];
					else
						zagito[p]= gcionidObject[p];
			zagito.gdt= zagito.gdt= nowDtNum();
			zagito.sav= 0;
			GCION.Sites.USAT.SetZagito(zagito);
			postzagito(zagito, 'Saved');
			GCION.Cookies.Cookie.Set('zagSession', status);
		} else {
			GCION.Sites.USAT.SetZagito(zagito);
			if ('PreSync' == GCION.Cookies.Cookie.Get('zagSession')) {
				GCION.Callbacks.ScheduleZag(zagito2Gci, 1);
				GCION.Cookies.Cookie.Set('zagSession', 'PreSynced');
			} else if (-1 < (""+GCION.Cookies.Cookie.Get('rsi_seg')).indexOf('10378')) {
				GCION.Cookies.Cookie.Set('zagSession', '0');
				doLoadZagito();
			} else {
				GCION.Cookies.Cookie.Set('zagSession', 'Ready');
			}
		}
	} else {
		GCION.Cookies.Cookie.Set('zagSession', 'GCI Down');
	}
}

function zagito2Gci(gcionidObject) {
	if (gcionidObject) {
		/* update zag, recording that we have updated GCI with our zagito data */
		var zagito= GCION.Sites.USAT.ZagitoObj();
		zagito.gci= gcionidObject.gcionid;
		zagito.gdt= nowDtNum();
		zagito.sav= 0;
		GCION.Sites.USAT.SetZagito(zagito);
		GCION.Cookies.Cookie.Set('zagSession', 'Synced');
		if (!zagito.sav) { // sav: no
			postzagito(zagito, 'Saved It');
		}
	} else {
		GCION.Cookies.Cookie.Set('zagSession', 'GCI down');
	}
}

function postzagito(data, finalState) {
	/* pack up GCION.Cookies.value into a query string,
	/* and tell postzagito about it */
	if (!data.kcd) data.kcd= 'testzag2'; // keycode
	var url= zagitoPrefix+'/postzagito.ashx';
	var delim='?';
	for (p in data)
		if (3 == p.length) {
			url+=delim+escape(p)+'='+escape(data[p]);
			delim='&';
		}
	var img= document.createElement('img');
	img.onload= function() {
		var zs= ''+GCION.Cookies.Cookie.Get("zagSession");
		if (-1 == zs.indexOf("error"))
			GCION.Cookies.Cookie.Set("zagSession", finalState);
	};
	img.setAttribute('src', url);
}

function doLoadZagito() {
	var url= document.URL;
	if (!zagEnabled) return;
	if (-1==url.indexOf(".htm")) return;
	if (-1<url.indexOf("usafront.htm")) return;
	var exclude= ['javascrip', '/survey/', 'marketing/legal.htm',
		'ads/usat/inside_usat.htm', 'money/jobcenter/front.htm',
		'educate/homesplash.htm', '_ads/sweepstakes', 'gannett.gcion.com',
		'subscribe.usatoday', 'newspaperads.com', 'ad.usatoday.com',
		'newstracker', 'marketing/feedback.htm', 'qasb.pqarchiver',
		'passport.com', 'moneyreg.aspx', 'portfolio.usatoday',
		'email.usatoday', 'registration.usatoday', 'careerbuilder.com',
		'eharmony.com', 'marketplace/front.htm', 'cars.com',
		'concordpromotions.com', 'shermanstravel.com', '.4info.net/nfl', '#'];
	var links= document.links;
	for (x= 0; x<links.length; x++) {
		var link=links[x]
		var href=link.href;
		var check= function(str) {return -1==href.indexOf(str)}
		var ok= -1==link.target.indexOf('popup');
		if (ok) for (var y= 0; y<exclude.length; y++) {
			if (!(ok= check(exclude[y]))) break;
		}
		if (ok) link.onclick= getZagitoLink(href);
	}
}

function getZagitoLink(href) {
	return function() {
		if (2 == parseInt(""+GCION.Cookies.Cookie.Get('zagCookie'))) {
			self.location= zagitoPrefix+'/zagito.htm?destination='+escape(href)+'&origination='+escape(window.location.toString());
			return false;
		} else
			return true;
	}
}

function pickup() {
	// system dropped cookies on floor, pick them up
	GCION.Cookies.Cookie.Set('zagSession', 'Saving');
	postzagito(GCION.Sites.USAT.ZagitoObj(), "Saved Session");
}


/*********************************************************
* fundamental zagito logic                               *
* invoked elsewhere, so interstitials can disable zagito *
*********************************************************/
function doLoad() {
	var sess= GCION.Cookies.Cookie.Get('zagSession');
	
	/* Call in Segment Map Beacon to save RevSci data for Rapt */
	if (null == sess) {
			
		 var img_v2= document.createElement('img');
		 img_v2.setAttribute('src', 'http://segmentmap.gannett.gcion.com/asp/segmentmapweb/segmentmapbeacon_V2.ashx');
		 img_v2.setAttribute('height', 1);
		 img_v2.setAttribute('width', 1);
		 document.body.appendChild(img_v2);
	}
	
	if ("0" == sess) {
		doLoadZagito();
	} else if (null == sess || 'Initialized' == sess || 'Session Saved' == sess) {
		zagito= ""+GCION.Cookies.Cookie.Get('zagCookie');
		var zver= parseInt(zagito);
		if (-1 < zagito.indexOf('n676474v')) { // have gdt means we synced with gci
			if (-1 < zagito.indexOf('n736176v0')) { // sav: no (not yet)
				pickup();
			} else {
				GCION.Cookies.Cookie.Set('zagSession', 'Done');
			}
		} else if (0 < zver && 2 != zver) { // zver 1 or 3+: user zagged
			if (-1 < zagito.indexOf('n676369v')) { // gci means we have gcionid
				GCION.Cookies.Cookie.Set('zagSession', 'Sync');
				GCION.Callbacks.ScheduleZag(zagito2Gci, 1);
			} else if (-1 < zagito.indexOf('n736176v0')) { // sav: no (not yet)
				pickup();
			} else { // no gcionid, not saved, get gcionid (and maybe zagito)
				GCION.Cookies.Cookie.Set('zagSession', 'PreSync');
				GCION.Callbacks.ScheduleZag(gci2Zagito, 0);
			}
		} else { // user not zagged, here, maybe elsewhere?
			GCION.Cookies.Cookie.Set('zagSession', 'Checking');
			GCION.Callbacks.ScheduleZag(gci2Zagito, 0)
		}
	}
}


/*OMNITURE CALL LOGIC*************************************************/



function uoTrack(obj) {
s_ut.linkTrackVars='prop41,prop1';
s_ut.linkTrackEvents='None';
s_ut.prop41=obj;
s_ut.tl(this,'o',obj +':  '+document.location.pathname);
}
function uoTrackSection(obj) {
s_ut.linkTrackVars='prop41,prop1';
s_ut.linkTrackEvents='None';
s_ut.prop41=obj;
document.location.pathname.search(/^\/([^\/]+)/);
s_ut.tl(this,'o',obj +':  '+RegExp.$1);
}
function uoTrackeVar9(obj) {
s_ut.linkTrackVars='eVar9,prop1';
s_ut.linkTrackEvents='None';
s_ut.eVar9=obj;
s_ut.tl(this,'o','ContextWeb');
}
/* SiteCatalyst code version: H.20.3.
Copyright 1997-2006 Omniture, Inc. 
More info available at http://www.omniture.com */
/* Specify the Report Suite ID(s) to track here */
var s_account="usatodayprod,gntbcstglobal"
var s_ut=s_gi(s_account)
/************************** CONFIG SECTION **************************/
s_ut.trackDownloadLinks=true
s_ut.linkDownloadFileTypes="exe,zip,wav,mp3,mov,mpg,avi,wmv,doc,pdf,xls"
s_ut.trackExternalLinks=true
s_ut.linkInternalFilters="javascript:,usatoday.com,cars,job,career,careerbuilder,salary,pgpartner,apartments,homescape,homefinder,homegain,forsalebyowner,quickenloans,vanlines,servicemagic,medicinenet,mixx,digg,del.icio.us,newsvine,reddit,facebook,twitter,fark,myspace,stumbleupon,propeller,linkedin"
s_ut.trackInlineStats=true
s_ut.linkLeaveQueryString=false
s_ut.linkTrackVars='prop1';
s_ut.linkTrackEvents="None"

/* WARNING: Changing the visitor namespace will cause drastic changes
to how your visitor data is collected.  Changes should only be made
when instructed to do so by your account manager.*/
s_ut.visitorNamespace="usatoday1"

var uohost = window.location.hostname;
var uopath = window.location.pathname;
if (window.uooverridepath) uopath = window.uooverridepath;
var uourl = uohost + uopath;

//if the domain is ours
if (uohost == "usatoday.com"  || uohost == "www.usatoday.com" || uohost == "asp.usatoday.com" || uohost == "content.usatoday.com") 
{
  //if there is no path or the url is pointing to default page
  if (uopath == "" || uopath == null || uopath == "/" || uourl == "www.usatoday.com/default.htm" || uourl == "usatoday.com/default.htm")
  {
    s_ut.pageName = 'usat :/';
  }
  //if there is a full path
  else
  {
     s_ut.pageName='usat :' + uopath;
  }
}

//if the domain is not ours
else
{
  //if the domain is not ours then it doesn't matter whether there is a path or not
  s_ut.pageName = 'usat :/' + uourl; 
}

//shorten page name based if application says so
if (window.usat_analytics_pagename_url) {
	var slashIndex = usat_analytics_pagename_url.indexOf('/') + 1;
	var truncatedPath = usat_analytics_pagename_url.substr(slashIndex);
	s_ut.pageName = 'usat :/' + truncatedPath; 
}

//adjust Travel URL if no pagename var found
if (!window.usat_analytics_pagename_url && location.host == "travel.usatoday.com") {
	s_ut.pageName = 'usat :/travel' + location.pathname; 
}



s_ut.prop1=document.location;

s_ut.server=window.location.hostname;


/*SSTS assignment for multi-personality pages */
if (window.usat_analytics_url) {
	var url = window.usat_analytics_url;
	url = url.replace("http://", "");
	url.match( /([^/]*)\/([^/]*)\/?([^/]*)\/?([^/]*)\/?([^/]*)\/?([^/]*)/); 
	var dir1=RegExp.$2;
	var dir2=RegExp.$3;
	var dir3=RegExp.$4;
	var dir4=RegExp.$5;
	
	s_ut.hier4=dir1;
	s_ut.channel=dir1;
	s_ut.prop17=dir1;

	if (dir4 != "") {
		s_ut.prop18=dir1 + ":" + dir2;
		s_ut.prop19=dir1 + ":" + dir2 + ":" + dir3;
		s_ut.prop20=dir1 + ":" + dir2 + ":" + dir3 + ":" + dir4;		
		s_ut.hier1=dir1 + "/" + dir2 + "/" + dir3 + "/" + dir4;
		s_ut.hier2="usatoday/" + dir1 + "/" + dir2 + "/" + dir3 + "/" + dir4;
	}  
	 else if (dir3 != "" && dir4 == "") {
		s_ut.prop18=dir1 + ":" + dir2;
		s_ut.prop19=dir1 + ":" + dir2 + ":" + dir3;
		s_ut.prop20=dir1 + ":" + dir2 + ":" + dir3;		
		s_ut.hier1=dir1 + "/" + dir2 + "/" + dir3;
		s_ut.hier2="usatoday/" + dir1 + "/" + dir2 + "/" + dir3;
	}
	 else if (dir2 != "" && dir3 == "") {
		s_ut.prop18=dir1 + ":" + dir2;
		s_ut.prop19=dir1 + ":" + dir2;
		s_ut.prop20=dir1 + ":" + dir2;		
		s_ut.hier1=dir1 + "/" + dir2;
		s_ut.hier2="usatoday/" + dir1 + "/" + dir2;
	}
	else if (dir1 != "" && dir2 == "") {
		s_ut.prop18=dir1;
		s_ut.prop19=dir1;
		s_ut.prop20=dir1;		
		s_ut.hier1=dir1;
		s_ut.hier2="usatoday/" + dir1;
	}
	else {
		s_ut.prop17="news";
		s_ut.prop18="news";
		s_ut.prop19="news";
		s_ut.prop20="news";		
		s_ut.hier1="news";
		s_ut.hier2="usatoday/news";		
		s_ut.channel=dir1;
		s_ut.hier4=dir1;
	}

} 

//populate Content Type based on page variables and/or page name		
		if (window.usat_analytics_gallery) {
		s_ut.prop16="galleries";		
		}		

		var oPageName = s_ut.pageName;
		var pos = oPageName.indexOf('/communities/');		
		
		if (pos>=0 || window.usat_communities_loc) {
		s_ut.prop16="communities";	
		
			if (window.usat_communities_loc) {
			var slashIndex = usat_communities_loc.indexOf('/communities/') + 13;
			var community = window.usat_communities_loc.substr(slashIndex).replace(/\/.*/, '');
			s_ut.prop2=community;				
			}
		
			else {
			var secondPath = oPageName.substr(19);
			var sdIndex = secondPath.indexOf('/');
			var secondDir = secondPath.substr(0, sdIndex);
			s_ut.prop2=secondDir;	
			}

		}
		
		var pos2 = oPageName.indexOf('/topics/topic/');
		
		if (pos2>=0) {
		s_ut.prop16="topics";	
		}

//populate evar9 for ContextWeb
s_ut.eVar9=['CW',
            document.location.pathname, ((self.usat_analytics_url||document.location.href.replace(/https*:\/\//, ''))+'/').split('/')[1], (self.ContextWebKeywords||'').replace(/kvcw=.*/,'').replace(/[^0-9+]/g,'')
].join(':');


//populate prop8 for Partners that have non-partner URLs
if (window.usat_analytics_partner_url) {
	var partnerName = usat_analytics_partner_url;
	s_ut.prop8=partnerName;
}

//populate props 43 and 45 if photo gallery page
if (window.usat_analytics_gallery) {
	
	if (window.usat_analytics_pagename_url) {
		var gallerySlashIndex = usat_analytics_pagename_url.indexOf('/') + 1;
		var galleryTruncatedPath = usat_analytics_pagename_url.substr(gallerySlashIndex);
		s_ut.prop43 = 'usat :/' + galleryTruncatedPath; 
	}

	if (window.usat_analytics_photogallery_image) {
		s_ut.prop45 = usat_analytics_photogallery_image; 
	}

}


/* Form Analysis Config */
s_ut.formList="feedbackForm,newsubForm"
s_ut.trackFormList=true
s_ut.trackPageName=true
s_ut.useCommerce=true
s_ut.varUsed="eVar6"
s_ut.eventList="event14,event15,event16" //Abandon,Success,Error

/* Plugin Config */
s_ut.usePlugins=true
function s_ut_doPlugins(s_ut) {
	/* Add calls to plugins here */
	var t = new Date();cct=t.getTime();
	var month = t.getMonth();var day = t.getDate();var year = t.getFullYear();
	var mon=['Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'];
	var thism=mon[month];
	var currentDate = (thism + year);String(currentDate);
	s_ut.events=s_ut.appendList(s_ut.events,"event3",",",1)	
	var temp1=s_ut.getQueryParam('loc');
	if(temp1){ s_ut.campaign='loc:'+temp1;s_ut.prop4='loc:'+temp1;s_ut.eVar25='loc:'+temp1 + ':' + currentDate};
	var temp2=s_ut.getQueryParam('campaign');
	if(temp2){s_ut.campaign='campaign:'+temp2;s_ut.prop4='campaign:'+temp2;s_ut.eVar25='campaign:'+temp2 + '-' + 	currentDate};
	if(!s_ut.eVar11)s_ut.eVar11=s_ut.getQueryParam('poe');
	if(!s_ut.eVar23)s_ut.eVar23=s_ut.getQueryParam('csp');
	if(s_ut.eVar23){if(!s_ut.eVar24){s_ut.eVar24=s_ut.getQueryParam('csp')}};
	s_ut.prop3=s_ut.eVar11;
	if(!s_ut.eVar7)s_ut.eVar7=s_ut.getQueryParam('q','kw')	
	if(s_ut.eVar7){var temp=s_ut.getValOnce(s_ut.eVar7,'ut_ust',0)};
	s_ut.prop46=s_ut.eVar7;
	if(temp){s_ut.events=s_ut.appendList(s_ut.events,'event6',',','1')}
	//var temp4=s_ut.getVisitNum();var temp5;
	var temp4;var temp5;
	if(temp1){temp5='loc:'+temp1};if(temp2){temp5='campaign:'+temp2};if(s_ut.eVar23){temp5='csp:'+s_ut.eVar23};
	s_ut.setupFormAnalysis();
	s_ut.prop15=s_ut.getDaysSinceLastVisit();
	s_ut.prop15=s_ut.getAndPersistValue(s_ut.prop15,'usat_dslv',0);

var queryparam1=s_ut.getQueryParam('type');
	if(queryparam1)
	{s_ut.pageName+='?type='+queryparam1};

s_ut.prop23=window.location.host+window.location.pathname+window.location.search;
s_ut.eVar20=window.location.host+window.location.pathname;
	s_ut.eVar1=s_ut.prop25;
	s_ut.eVar2=s_ut.prop17;
	s_ut.eVar3=s_ut.eVar1+':'+s_ut.eVar2;
	s_ut.eVar4=s_ut.pageName;
	var currentDate = new Date();
	s_ut.prop12=s_ut.getTimeParting('h','-5',currentDate.getFullYear());s_ut.eVar29=s_ut.prop12;
	s_ut.prop13=s_ut.getTimeParting('d','-5',currentDate.getFullYear()); 
        s_ut.prop14=s_ut.getTimeParting('w','-5',currentDate.getFullYear());
       /* Repeat Visitor by campaign - Added by Mark Stringham Omniture IC */
	var isFtcv = s_ut.c_r('s_ftcv');
        var ex=new Date();ct=ex.getTime();ex.setTime(ct+90*24*60*60*1000) // 90 days expire;
        if((temp5) && (temp4==1) && (!isFtcv))
        {s_ut.c_w('s_ftcv',temp5,ex);s_ut.events=s_ut.appendList(s_ut.events,'event11',',','1') // Set FT visit event;
        s_ut.eVar26=temp5;s_ut.eVar27=currentDate;}
        if((isFtcv) && (temp4!=1)){s_ut.events=s_ut.appendList(s_ut.events,'event12',',','1')}//Set Repeat visit event;
      /* End Repeat Visitor by campaign */  
        
}
s_ut.doPlugins=s_ut_doPlugins

/************************** PLUGINS SECTION *************************/

/*
 * Plugin: getQueryParam 2.0 - return query string parameter(s)
 */
s_ut.getQueryParam=new Function("p","d","u",""
+"var s=this,v='',i,t;d=d?d:'';u=u?u:(s.pageURL?s.pageURL:''+s.wd.loc"
+"ation);u=u=='f'?''+s.gtfs().location:u;while(p){i=p.indexOf(',');i="
+"i<0?p.length:i;t=s.p_gpv(p.substring(0,i),u);if(t)v+=v?d+t:t;p=p.su"
+"bstring(i==p.length?i:i+1)}return v");
s_ut.p_gpv=new Function("k","u",""
+"var s=this,v='',i=u.indexOf('?'),q;if(k&&i>-1){q=u.substring(i+1);v"
+"=s.pt(q,'&','p_gvf',k)}return v");
s_ut.p_gvf=new Function("t","k",""
+"if(t){var s=this,i=t.indexOf('='),p=i<0?t:t.substring(0,i),v=i<0?'T"
+"rue':t.substring(i+1);if(p.toLowerCase()==k.toLowerCase())return s."
+"epa(v)}return ''");
/*
 * Plugin: Form Analysis 2.0 (Success, Error, Abandonment)
 */
s_ut.setupFormAnalysis=new Function(""
+"var s=this;if(!s.fa){s.fa=new Object;var f=s.fa;f.ol=s.wd.onload;s."
+"wd.onload=s.faol;f.uc=s.useCommerce;f.vu=s.varUsed;f.vl=f.uc?s.even"
+"tList:'';f.tfl=s.trackFormList;f.fl=s.formList;f.va=new Array('',''"
+",'','')}");
s_ut.sendFormEvent=new Function("t","pn","fn","en",""
+"var s=this,f=s.fa;t=t=='s'?t:'e';f.va[0]=pn;f.va[1]=fn;f.va[3]=t=='"
+"s'?'Success':en;s.fasl(t);f.va[1]='';f.va[3]='';");
s_ut.faol=new Function("e",""
+"var s=s_c_il["+s_ut._in+"],f=s.fa,r=true,fo,fn,i,en,t,tf;if(!e)e=s.wd."
+"event;f.os=new Array;if(f.ol)r=f.ol(e);if(s.d.forms&&s.d.forms.leng"
+"th>0){for(i=s.d.forms.length-1;i>=0;i--){fo=s.d.forms[i];fn=fo.name"
+";tf=f.tfl&&s.pt(f.fl,',','ee',fn)||!f.tfl&&!s.pt(f.fl,',','ee',fn);"
+"if(tf){f.os[fn]=fo.onsubmit;fo.onsubmit=s.faos;f.va[1]=fn;f.va[3]='"
+"No Data Entered';for(en=0;en<fo.elements.length;en++){el=fo.element"
+"s[en];t=el.type;if(t&&t.toUpperCase){t=t.toUpperCase();var md=el.on"
+"mousedown,kd=el.onkeydown,omd=md?md.toString():'',okd=kd?kd.toStrin"
+"g():'';if(omd.indexOf('.fam(')<0&&okd.indexOf('.fam(')<0){el.s_famd"
+"=md;el.s_fakd=kd;el.onmousedown=s.fam;el.onkeydown=s.fam}}}}}f.ul=s"
+".wd.onunload;s.wd.onunload=s.fasl;}return r;");
s_ut.faos=new Function("e",""
+"var s=s_c_il["+s_ut._in+"],f=s.fa,su;if(!e)e=s.wd.event;if(f.vu){s[f.v"
+"u]='';f.va[1]='';f.va[3]='';}su=f.os[this.name];return su?su(e):tru"
+"e;");
s_ut.fasl=new Function("e",""
+"var s=s_c_il["+s_ut._in+"],f=s.fa,a=f.va,l=s.wd.location,ip=s.trackPag"
+"eName,p=s.pageName;if(a[1]!=''&&a[3]!=''){a[0]=!p&&ip?l.host+l.path"
+"name:a[0]?a[0]:p;if(!f.uc&&a[3]!='No Data Entered'){if(e=='e')a[2]="
+"'Error';else if(e=='s')a[2]='Success';else a[2]='Abandon'}else a[2]"
+"='';var tp=ip?a[0]+':':'',t3=e!='s'?':('+a[3]+')':'',ym=!f.uc&&a[3]"
+"!='No Data Entered'?tp+a[1]+':'+a[2]+t3:tp+a[1]+t3,ltv=s.linkTrackV"
+"ars,lte=s.linkTrackEvents,up=s.usePlugins;if(f.uc){s.linkTrackVars="
+"ltv=='None'?f.vu+',events':ltv+',events,'+f.vu;s.linkTrackEvents=lt"
+"e=='None'?f.vl:lte+','+f.vl;f.cnt=-1;if(e=='e')s.events=s.pt(f.vl,'"
+",','fage',2);else if(e=='s')s.events=s.pt(f.vl,',','fage',1);else s"
+".events=s.pt(f.vl,',','fage',0)}else{s.linkTrackVars=ltv=='None'?f."
+"vu:ltv+','+f.vu}s[f.vu]=ym;s.usePlugins=false;s.tl(true,'o','Form A"
+"nalysis');s[f.vu]='';s.usePlugins=up}return f.ul&&e!='e'&&e!='s'?f."
+"ul(e):true;");
s_ut.fam=new Function("e",""
+"var s=s_c_il["+s_ut._in+"],f=s.fa;if(!e) e=s.wd.event;var o=s.trackLas"
+"tChanged,et=e.type.toUpperCase(),t=this.type.toUpperCase(),fn=this."
+"form.name,en=this.name,sc=false;if(document.layers){kp=e.which;b=e."
+"which}else{kp=e.keyCode;b=e.button}et=et=='MOUSEDOWN'?1:et=='KEYDOW"
+"N'?2:et;if(f.ce!=en||f.cf!=fn){if(et==1&&b!=2&&'BUTTONSUBMITRESETIM"
+"AGERADIOCHECKBOXSELECT-ONEFILE'.indexOf(t)>-1){f.va[1]=fn;f.va[3]=e"
+"n;sc=true}else if(et==1&&b==2&&'TEXTAREAPASSWORDFILE'.indexOf(t)>-1"
+"){f.va[1]=fn;f.va[3]=en;sc=true}else if(et==2&&kp!=9&&kp!=13){f.va["
+"1]=fn;f.va[3]=en;sc=true}if(sc){nface=en;nfacf=fn}}if(et==1&&this.s"
+"_famd)return this.s_famd(e);if(et==2&&this.s_fakd)return this.s_fak"
+"d(e);");
s_ut.ee=new Function("e","n",""
+"return n&&n.toLowerCase?e.toLowerCase()==n.toLowerCase():false;");
s_ut.fage=new Function("e","a",""
+"var s=this,f=s.fa,x=f.cnt;x=x?x+1:1;f.cnt=x;return x==a?e:'';");
/*
 * Utility Function: split v1.5 - split a string (JS 1.0 compatible)
 */
s_ut.split=new Function("l","d",""
+"var i,x=0,a=new Array;while(l){i=l.indexOf(d);i=i>-1?i:l.length;a[x"
+"++]=l.substring(0,i);l=l.substring(i+d.length);}return a");
/*
 * Plugin Utility: appendList v1.0
 */
s_ut.appendList=new Function("L","v","d","u",""
+"var s=this,m=0;if(!L)L='';if(u){var i,n,a=s.split(L,d);for(i in a){"
+"n=a[i];m=m||(u==1?(n==v):(n.toLowerCase()==v.toLowerCase()));}}if(!"
+"m)L=L?L+d+v:v;return L");

/*
 * Function - read combined cookies v 0.2
 */
/*
s_ut.c_rr=s_ut.c_r;
s_ut.c_r=new Function("k",""
+"var s=this,d=new Date,v=s.c_rr(k),c=s.c_rr('s_pers'),i,m,e;if(v)ret"
+"urn v;k=s.ape(k);i=c.indexOf(' '+k+'=');c=i<0?s.c_rr('s_sess'):c;i="
+"c.indexOf(' '+k+'=');m=i<0?i:c.indexOf('|',i);e=i<0?i:c.indexOf(';'"
+",i);m=m>0?m:e;v=i<0?'':s.epa(c.substring(i+2+k.length,m<0?c.length:"
+"m));if(m>0&&m!=e)if(parseInt(c.substring(m+1,e<0?c.length:e))<d.get"
+"Time()){d.setTime(d.getTime()-60000);s.c_w(s.epa(k),'',d);v='';}ret"
+"urn v;");
*/

/*
 * Function - write combined cookies v 0.2
 */
/*
s_ut.c_wr=s_ut.c_w;
s_ut.c_w=new Function("k","v","e",""
+"var s=this,d=new Date,ht=0,pn='s_pers',sn='s_sess',pc=0,sc=0,pv,sv,"
+"c,i,t;d.setTime(d.getTime()-60000);if(s.c_rr(k)) s.c_wr(k,'',d);k=s"
+".ape(k);pv=s.c_rr(pn);i=pv.indexOf(' '+k+'=');if(i>-1){pv=pv.substr"
+"ing(0,i)+pv.substring(pv.indexOf(';',i)+1);pc=1;}sv=s.c_rr(sn);i=sv"
+".indexOf(' '+k+'=');if(i>-1){sv=sv.substring(0,i)+sv.substring(sv.i"
+"ndexOf(';',i)+1);sc=1;}d=new Date;if(e){if(e.getTime()>d.getTime())"
+"{pv+=' '+k+'='+s.ape(v)+'|'+e.getTime()+';';pc=1;}}else{sv+=' '+k+'"
+"='+s.ape(v)+';';sc=1;}if(sc) s.c_wr(sn,sv,0);if(pc){t=pv;while(t&&t"
+".indexOf(';')!=-1){var t1=parseInt(t.substring(t.indexOf('|')+1,t.i"
+"ndexOf(';')));t=t.substring(t.indexOf(';')+1);ht=ht<t1?t1:ht;}d.set"
+"Time(ht);s.c_wr(pn,pv,d);}return v==s.c_r(s.epa(k));");
*/

/*
 * Plugin: Days since last Visit 1.0.H
 */
s_ut.getDaysSinceLastVisit=new Function(""
+"var s=this,e=new Date(),cval,ct=e.getTime(),c='s_lastvisit',day=24*"
+"60*60*1000;e.setTime(ct+3*365*day);cval=s_ut.c_r(c);if(!cval){s_ut.c_w(c,"
+"ct,e);return 'First Visit or cookies not supported';}else{var d"
+"=ct-cval;if(d>30*60*1000){if(d>30*day){s_ut.c_w(c,ct,e);return 'More t"
+"han 30 days';}if(d<30*day+1 && d>7*day){s_ut.c_w(c,ct,e);return 'More "
+"than 7 days';}if(d<7*day+1 && d>day){s_ut.c_w(c,ct,e);return 'Less tha"
+"n 7 days';}if(d<day+1){s_ut.c_w(c,ct,e);return 'Less than 1 day';}}els"
+"e return '';}"
);

/*
 * Plugin: getAndPersistValue 0.3 - get a value on every page
 */
s_ut.getAndPersistValue=new Function("v","c","e",""
+"var s=this,a=new Date;e=e?e:0;a.setTime(a.getTime()+e*86400000);if("
+"v)s_ut.c_w(c,v,e?a:0);return s_ut.c_r(c);");

/*
 * Plugin: getValOnce 0.2 - get a value once per session or number of days
 */
s_ut.getValOnce=new Function("v","c","e",""
+"var s=this,k=s_ut.c_r(c),a=new Date;e=e?e:0;if(v){a.setTime(a.getTime("
+")+e*86400000);s_ut.c_w(c,v,e?a:0);}return v==k?'':v");

/*
 * Plugin: getTimeParting 1.3 - Set timeparting values based on time zone
 */

s_ut.getTimeParting=new Function("t","z","y",""
+"dc=new Date('1/1/2000');f=15;ne=8;if(dc.getDay()!=6||"
+"dc.getMonth()!=0){return'Data Not Available'}else{;z=parseInt(z);"
+"if(y=='2009'){f=8;ne=1};gmar=new Date('3/1/'+y);dsts=f-gmar.getDay("
+");gnov=new Date('11/1/'+y);dste=ne-gnov.getDay();spr=new Date('3/'"
+"+dsts+'/'+y);fl=new Date('11/'+dste+'/'+y);cd=new Date();"
+"if(cd>spr&&cd<fl){z=z+1}else{z=z};utc=cd.getTime()+(cd.getTimezoneO"
+"ffset()*60000);tz=new Date(utc + (3600000*z));thisy=tz.getFullYear("
+");var days=['Sunday','Monday','Tuesday','Wednesday','Thursday','Fr"
+"iday','Saturday'];if(thisy!=y){return'Data Not Available'}else{;thi"
+"sh=tz.getHours();thismin=tz.getMinutes();thisd=tz.getDay();var dow="
+"days[thisd];var ap='AM';var dt='Weekday';var mint='00';if(thismin>3"
+"0){mint='30'}if(thish>=12){ap='PM';thish=thish-12};if (thish==0){th"
+"ish=12};if(thisd==6||thisd==0){dt='Weekend'};var timestring=thish+'"
+":'+mint+ap;var daystring=dow;var endstring=dt;if(t=='h'){return tim"
+"estring}if(t=='d'){return daystring};if(t=='w'){return en"
+"dstring}}};"
);


/*                                                                  
 * Plugin: Visit Number Expire in 5 years  - Return the user visit number 
 */
s_ut.getVisitNum=new Function(""
+"var s=this,e=new Date(),cval,cvisit,ct=e.getTime(),c='s_vnum',c2='s"
+"_invisit';e.setTime(ct+5*365*24*60*60*1000);cval=s.c_r(c);if(cval){var"
+" i=cval.indexOf('&vn='),str=cval.substring(i+4,cval.length),k;}cvis"
+"it=s.c_r(c2);if(cvisit){if(str){e.setTime(ct+30*60*1000);s.c_w(c2,'"
+"true',e);return str;}else return 'unknown visit number';}else{if(st"
+"r){str++;k=cval.substring(0,i);e.setTime(k);s.c_w(c,k+'&vn='+str,e)"
+";e.setTime(ct+30*60*1000);s.c_w(c2,'true',e);return str;}else{s.c_w"
+"(c,ct+5*365*24*60*60*1000+'&vn=1',e);e.setTime(ct+30*60*1000);s.c_w(c2"
+",'true',e);return 1;}}"
);


/************* DO NOT ALTER ANYTHING BELOW THIS LINE ! **************/
var s_code='',s_objectID;function s_gi(un,pg,ss){var c="=fun`o(~.substring(~){`Ps=^O~.indexOf(~#2 ~;$2~`b$2~=new Fun`o(~.length~.toLowerCase()~`Ps#8c_#k^an+'],~=new Object~};s.~`YMigrationServer~.toU"
+"pperCase~){$2~','~s.wd~);s.~')q='~=new Array~ookieDomainPeriods~.location~^LingServer~dynamicAccount~var ~link~s.m_~=='~s.apv~BufferedRequests~Element~)$2x^b!Object#WObject.prototype#WObject.protot"
+"ype[x])~etTime~visitor~$w@c(~referrer~else ~s.pt(~s.maxDelay~}c#E(e){~#i+~=''~.lastIndexOf(~^wc_i~}$2~.protocol~=new Date~^wobjectID=s.ppu=$I=$Iv1=$Iv2=$Iv3~for(i=~ction~javaEnabled~onclick~Name~te"
+"rnalFilters~javascript~s.dl~@6s.b.addBehavior(\"# default# ~=parseFloat(~typeof(v)==\"~window~cookie~while(~s.vl_g~Type~;i#U{~tfs~s.un~&&s.~o^woid~browser~.parent~document~colorDepth~String~.host~s"
+".fl(~s.rep(~s.eo~'+tm@S~s.sq~parseInt(~t=s.ot(o)~track~nload~j='1.~this~#PURL~}else{~s.vl_l~lugins~'){q='~dynamicVariablePrefix~');~;for(~Sampling~s.rc[un]~Event~._i~&&(~loadModule~resolution~s.c_r"
+"(~s.c_w(~s.eh~s.isie~\"m_\"+n~Secure~Height~tcf~isopera~ismac~escape(~'s_~.href~screen.~s#8gi(~Version~harCode~variableProvider~.s_~)s_sv(v,n[k],i)}~')>=~){s.~)?'Y':'N'~u=m[t+1](~i)clearTimeout(~e&"
+"&l$bSESSION'~name~home#P~;try{~,$m)~s.ssl~s.oun~s.rl[u~Width~o.type~s.vl_t~=s.sp(~Lifetime~s.gg('objectID~sEnabled~'+n+'~.mrq(@wun+'\"~ExternalLinks~charSet~lnk~onerror~http~currencyCode~.src~disab"
+"le~.get~MigrationKey~(''+~&&!~f',~){t=~r=s[f](~u=m[t](~Opera~Math.~s.ape~s.fsg~s.ns6~conne~InlineStats~&&l$bNONE'~Track~'0123456789~true~+\"_c\"]~s.epa(~t.m_nl~s.va_t~m._d~n=s.oid(o)~,'sqs',q);~Lea"
+"veQuery~?'&~'=')~n){~\"'+~){n=~'_'+~'+n;~\",''),~,255)}~if(~vo)~s.sampled~=s.oh(o);~+(y<1900?~n]=~1);~&&o~:'';h=h?h~;'+(n?'o.~sess~campaign~lif~ in ~s.co(~ffset~s.pe~m._l~s.c_d~s.brl~s.nrs~s[mn]~,'"
+"vo~s.pl~=(apn~space~\"s_gs(\")~vo._t~b.attach~2o7.net'~Listener~Year(~d.create~=s.n.app~)}}}~!='~'||t~)+'/~s()+'~){p=~():''~a['!'+t]~&&c){~://')i+=~){v=s.n.~channel~100~rs,~.target~o.value~s_si(t)~"
+"')dc='1~\".tl(\")~etscape~s_')t=t~omePage~='+~&&t~[b](e);~\"){n[k]~';s.va_~a+1,b):~return~mobile~height~events~random~code~=s_~=un~,pev~'MSIE ~'fun~floor(~atch~transa~s.num(~m._e~s.c_gd~,'lt~tm.g~."
+"inner~;s.gl(~,f1,f2~',s.bc~page~Group,~.fromC~sByTag~')<~++)~)){~||!~+';'~i);~y+=~l&&~''+x~[t]=~[i]=~[n];~' '+~'+v]~>=5)~:'')~+1))~il['+s~!a[t])~~s._c=^pc';`H=`y`5!`H`i@v`H`il`K;`H`in=0;}s^al=`H`il"
+";s^an=`H`in;s^al[s^a$7s;`H`in++;s.an#8an;s.cls`0x,c){`Pi,y`g`5!c)c=^O.an;`n0;i<x`8^3n=x`1i,i+1)`5c`3n)>=0)#Zn}`4y`Cfl`0x,l){`4x?@Ux)`10,l):x`Cco`0o`F!o)`4o;`Pn`B,x^Wx$Fo)$2x`3'select#T0&&x`3'filter"
+"#T0)n[x]=o[x];`4n`Cnum`0x){x`g+x^W`Pp=0;p<x`8;p#U$2(@j')`3x`1p,p#j<0)`40;`41`Crep#8rep;s.sp#8sp;s.jn#8jn;@c`0x`2,h=@jABCDEF',i,c=s.@L,n,l,e,y`g;c=c?c`E$g`5x){x`g+x`5c`SAUTO'^b'').c^uAt){`n0;i<x`8^3"
+"c=x`1i,i+$8n=x.c^uAt(i)`5n>127){l=0;e`g;^0n||l<4){e=h`1n%16,n%16+1)+e;n=(n-n%16)/16;l++}#Z'%u'+e}`6c`S+')#Z'%2B';`b#Z^oc)}x=y^Qx=x?^F^o#b),'+`G%2B'):x`5x&&c^6em==1&&x`3'%u#T0&&x`3'%U#T0){i=x`3'%^V^"
+"0i>=0){i++`5h`18)`3x`1i,i+1)`E())>=0)`4x`10,i)+'u00'+x`1#Yi=x`3'%',i$a}`4x`Cepa`0x`2;`4x?un^o^F#b,'+`G ')):x`Cpt`0x,d,f,a`2,t=x,z=0,y,r;^0t){y=t`3d);y=y<0?t`8:y;t=t`10,y);@Yt,a)`5r)`4r;z+=y+d`8;t=x"
+"`1z,x`8);t=z<x`8?t:''}`4''`Cisf`0t,a){`Pc=a`3':')`5c>=0)a=a`10,c)`5t`10,2)`S$u`12);`4(t!`g$x==a)`Cfsf`0t,a`2`5`ca,`G,'is@Wt))@d+=(@d!`g?`G`ft;`40`Cfs`0x,f`2;@d`g;`cx,`G,'fs@Wf);`4@d`Csi`0wd`2,c`g+s"
+"_gi,a=c`3\"{\"),b=c`h\"}\"),m;c#8fe(a>0&&b>0?c`1#10)`5wd&&wd.^A$iwd.s`Xout(#C`o s_sv(o,n,k){`Pv=o[k],i`5v`F`xstring\"||`xnumber\")n[k]=v;`bif (`xarray$z`K;`n0;i<v`8;i++^x`bif (`xobject$z`B^Wi$Fv^x}"
+"}fun`o $q{`Pwd=`y,s,i,j,c,a,b;wd^wgi`7\"un\",\"pg\",\"ss\",@wc+'\");wd.^s@w@9+'\");s=wd.s;s.sa(@w^5+'\"`I^4=wd;`c^1,\",\",\"vo1\",t`I@M=^G=s.`Q`r=s.`Q^2=`H`m=\\'\\'`5t.m_#a@n)`n0;i<@n`8^3n=@n[i]`5@"
+"vm=t#ec=t[^i]`5m$ic=\"\"+c`5c`3\"fun`o\")>=0){a=c`3\"{\");b=c`h\"}\");c=a>0&&b>0?c`1#10;s[^i@l=c`5#H)s.^c(n)`5s[n])for(j=0;j<$J`8;j#Us_sv(m,s[n],$J[j]$a}}`Pe,o,t@6o=`y.opener`5o$9^wgi@Xo^wgi(@w^5+'"
+"\")`5t)$q}`e}',1)}`Cc_d`g;#If`0t,a`2`5!#Gt))`41;`40`Cc_gd`0`2,d=`H`M^D@4,n=s.fpC`L,p`5!n)n=s.c`L`5d@V$K@xn?^Jn):2;n=n>2?n:2;p=d`h'.')`5p>=0){^0p>=0&&n>1$fd`h'.',p-$8n--}$K=p>0&&`cd,'.`Gc_gd@W0)?d`1"
+"p):d}}`4$K`Cc_r`0k`2;k=@c(k);`Pc=#fs.d.`z,i=c`3#fk+@u,e=i<0?i:c`3';',i),v=i<0?'':@mc`1i+2+k`8,e<0?c`8:e));`4v$b[[B]]'?v:''`Cc_w`0k,v,e`2,d=#I(),l=s.`z@F,t;v`g+v;l=l?@Ul)`E$g`5@3@h@X(v!`g?^Jl?l:0):-"
+"60)`5t){e`l;e.s`X(e.g`X()+(t*$m0))}`jk@h^zd.`z=k+'`Zv!`g?v:'[[B]]')+'; path=/;'+(@3?' expires$we.toGMT^C()#X`f(d?' domain$wd#X:'^V`4^ek)==v}`40`Ceh`0o,e,r,f`2,b=^p'+e+@ys^an,n=-1,l,i,x`5!^gl)^gl`K;"
+"l=^gl;`n0;i<l`8&&n<0;i++`Fl[i].o==o&&l[i].e==e)n=i`jn<0@xi;l[n]`B}x=l#ex.o=o;x.e=e;f=r?x.b:f`5r||f){x.b=r?0:o[e];x.o[e]=f`jx.b){x.o[b]=x.b;`4b}`40`Ccet`0f,a,t,o,b`2,r,^l`5`T>=5^b!s.^m||`T>=7#V^l`7'"
+"s`Gf`Ga`Gt`G`Pe,r@6@Ya)`er=s[t](e)}`4r^Vr=^l(s,f,a,t)^Q$2s.^n^6u`3#B4^y0)r=s[b](a);else{^g(`H,'@N',0,o);@Ya`Ieh(`H,'@N',1)}}`4r`Cg^4et`0e`2;`4s.^4`Cg^4oe`7'e`G`Ac;^g(`y,\"@N\",1`Ie^4=1;c=s.t()`5c)s"
+".d.write(c`Ie^4=0;`4@k'`Ig^4fb`0a){`4`y`Cg^4f`0w`2,p=w^9,l=w`M;s.^4=w`5p&&p`M!=#ap`M^D==l^D^z^4=p;`4s.g^4f(s.^4)}`4s.^4`Cg^4`0`2`5!s.^4^z^4=`H`5!s.e^4)s.^4=s.cet('g^4@Ws.^4,'g^4et',s.g^4oe,'g^4fb')"
+"}`4s.^4`Cmrq`0u`2,l=@A],n,r;@A]=0`5l)for(n=0;n<l`8;n#U{r=l#es.mr(0,0,r.r,0,r.t,r.u)}`Cbr`0id,rs`2`5s.@R`U#W^f^pbr',rs))$L=rs`Cflush`U`0){^O.fbr(0)`Cfbr`0id`2,br=^e^pbr')`5!br)br=$L`5br`F!s.@R`U)^f^"
+"pbr`G'`Imr(0,0,br)}$L=0`Cmr`0$C,q,$nid,ta,u`2,dc=s.dc,t1=s.`N,t2=s.`N^j,tb=s.`NBase,p='.sc',ns=s.`Y`r$R,un=s.cls(u?u:(ns?ns:s.fun)),r`B,l,imn=^pi_'+(un),im,b,e`5!rs`Ft1`Ft2^6ssl)t1=t2^Q$2!tb)tb='$V"
+"`5dc)dc=@Udc)`9;`bdc='d1'`5tb`S$V`Fdc`Sd1$r12';`6dc`Sd2$r22';p`g}t1#9+'.'+dc+'.'+p+tb}rs='@O'+(@8?'s'`f'://'+t1+'/b/ss/'+^5+'/'+(s.#3?'5.1':'1'$dH.20.3/'+$C+'?AQB=1&ndh=1'+(q?q`f'&AQE=1'`5^h@Vs.^n`"
+"F`T>5.5)rs=^E$n4095);`brs=^E$n2047)`jid^zbr(id,rs);#2}`js.d.images&&`T>=3^b!s.^m||`T>=7)^b@e<0||`T>=6.1)`F!s.rc)s.rc`B`5!^Y){^Y=1`5!s.rl)s.rl`B;@An]`K;s`Xout('$2`y`il)`y`il['+s^an+']@J)',750)^Ql=@A"
+"n]`5l){r.t=ta;r.u#9;r.r=rs;l[l`8]=r;`4''}imn+=@y^Y;^Y++}im=`H[imn]`5!im)im=`H[im$7new Image;im^wl=0;im.o^M`7'e`G^O^wl=1;`Pwd=`y,s`5wd`il){s=wd`il['+s^an+'];s@J`Inrs--`5!$M)`Rm(\"rr\")}')`5!$M^znrs="
+"1;`Rm('rs')}`b$M++;im@Q=rs`5rs`3'&pe=^y0^b!ta||ta`S_self$ca`S_top'||(`H.@4$xa==`H.@4)#Vb=e`l;^0!im^w#ae.g`X()-b.g`X()<500)e`l}`4''}`4'<im'+'g sr'+'c=@wrs+'\" width=1 #4=1 border=0 alt=\"\">'`Cgg`0v"
+"`2`5!`H[^p#g)`H[^p#g`g;`4`H[^p#g`Cglf`0t,a`Ft`10,2)`S$u`12);`Ps=^O,v=s.gg(t)`5v)s#cv`Cgl`0v`2`5s.pg)`cv,`G,'gl@W0)`Crf`0x`2,y,i,j,h,l,a,b`g,c`g,t`5x){y`g+x;i=y`3'?')`5i>0){a=y`1i+$8y=y`10,#Yh=y`9;i"
+"=0`5h`10,7)`S@O$j7;`6h`10,8)`S@Os$j8;h=h`1#Yi=h`3\"/\")`5i>0){h=h`10,i)`5h`3'google^y0){a@Ea,'&')`5a`8>1){l=',q,ie,start,search_key,word,kw,cd,'^Wj=0;j<a`8;j++@Xa[j];i=t`3@u`5i>0&&l`3`G+t`10,i)+`G)"
+">=0)b+=(b@t'`ft;`bc+=(c@t'`ft`jb$i#Z'?'+b+'&'+c`5#b!=y)x=y}}}}}}`4x`Chav`0`2,qs`g,fv=s.`Q@iVa$nfe=s.`Q@i^Zs,mn,i`5$I){mn=$I`10,1)`E()+$I`11)`5$N){fv=$N.^LVars;fe=$N.^L^Zs}}fv=fv?fv+`G+^R+`G+^R2:'';"
+"`n0;i<@o`8^3`Pk=@o[i],v=s[k],b=k`10,4),x=k`14),n=^Jx),q=k`5v&&k$b`Q`r'&&k$b`Q^2'`F$I||s.@M||^G`Ffv^b`G+fv+`G)`3`G+k+`G)<0)v`g`5k`S#5'&&fe)v=s.fs(v,fe)`jv`Fk`S^U`JD';`6k`S`YID`Jvid';`6k`S^P^Tg';v=^E"
+"v$1`6k`S`a^Tr';v=^Es.rf(v)$1`6k`Svmk'||k`S`Y@T`Jvmt';`6k`S`D^Tvmf'`5@8^6`D^j)v`g}`6k`S`D^j^Tvmf'`5!@8^6`D)v`g}`6k`S@L^Tce'`5v`E()`SAUTO')v='ISO8859-1';`6s.em==2)v='UTF-8'}`6k`S`Y`r$R`Jns';`6k`Sc`L`"
+"Jcdp';`6k`S`z@F`Jcl';`6k`S^v`Jvvp';`6k`S@P`Jcc';`6k`S$l`Jch';`6k`S#F`oID`Jxact';`6k`S$D`Jv0';`6k`S^d`Js';`6k`S^B`Jc';`6k`S`t^t`Jj';`6k`S`p`Jv';`6k`S`z@H`Jk';`6k`S^8@B`Jbw';`6k`S^8^k`Jbh';`6k`S@f`o^"
+"2`Jct';`6k`S@5`Jhp';`6k`Sp^S`Jp';`6#Gx)`Fb`Sprop`Jc@z`6b`SeVar`Jv@z`6b`Slist`Jl@z`6b`Shier^Th@zv=^Ev$1`jv)qs+='&'+q+'$w(k`10,3)$bpev'?@c(v):v$a`4qs`Cltdf`0t,h@Xt?t`9$A`9:'';`Pqi=h`3'?^Vh=qi>=0?h`10"
+",qi):h`5t&&h`1h`8-(t`8#j`S.'+t)`41;`40`Cltef`0t,h@Xt?t`9$A`9:''`5t&&h`3t)>=0)`41;`40`Clt`0h`2,lft=s.`QDow^MFile^2s,lef=s.`QEx`s,$E=s.`QIn`s;$E=$E?$E:`H`M^D@4;h=h`9`5s.^LDow^MLinks&&lft&&`clft,`G#Jd"
+"@Wh))`4'd'`5s.^L@K&&h`10,1)$b# '^blef||$E)^b!lef||`clef,`G#Je@Wh))^b!$E#W`c$E,`G#Je@Wh)))`4'e';`4''`Clc`7'e`G`Ab=^g(^O,\"`q\"`I@M=$G^O`It(`I@M=0`5b)`4^O$y`4@k'`Ibc`7'e`G`Af,^l`5s.d^6d.all^6d.all.cp"
+"pXYctnr)#2;^G=e@Q`V?e@Q`V:e$o;^l`7\"s\",\"`Pe@6$2^G^b^G.tag`r||^G^9`V||^G^9Node))s.t()`e}\");^l(s`Ieo=0'`Ioh`0o`2,l=`H`M,h=o^q?o^q:'',i,j,k,p;i=h`3':^Vj=h`3'?^Vk=h`3'/')`5h^bi<0||(j>=0&&i>j)||(k>=0"
+"&&i>k))$fo`k$9`k`8>1?o`k:(l`k?l`k:'^Vi=l.path@4`h'/^Vh=(p?p+'//'`f(o^D?o^D:(l^D?l^D#i)+(h`10,1)$b/'?l.path@4`10,i<0?0:i$d'`fh}`4h`Cot`0o){`Pt=o.tag`r;t=t$x`E?t`E$g`5t`SSHAPE')t`g`5t`Ft`SINPUT'&&@C&"
+"&@C`E)t=@C`E();`6!t$9^q)t='A';}`4t`Coid`0o`2,^K,p,c,n`g,x=0`5t@V^7$fo`k;c=o.`q`5o^q^bt`SA$c`SAREA')^b!c#Wp||p`9`3'`t#T0))n$5`6c@x^Fs.rep(^Fs.rep@Uc,\"\\r$0\"\\n$0\"\\t$0' `G^Vx=2}`6$p^bt`SINPUT$c`S"
+"SUBMIT')@x$p;x=3}`6o@Q$x`SIMAGE')n=o@Q`5@v^7=^En@7;^7t=x}}`4^7`Crqf`0t,un`2,e=t`3@u,u=e>=0?`G+t`10,e)+`G:'';`4u&&u`3`G+un+`G)>=0?@mt`1e#j:''`Crq`0un`2,c#9`3`G),v=^e^psq'),q`g`5c<0)`4`cv,'&`Grq@Wun)"
+";`4`cun,`G,'rq',0)`Csqp`0t,a`2,e=t`3@u,q=e<0?'':@mt`1e+1)`Isqq[q]`g`5e>=0)`ct`10,e),`G@r`40`Csqs`0un,q`2;^Iu[u$7q;`40`Csq`0q`2,k=^psq',v=^ek),x,c=0;^Iq`B;^Iu`B;^Iq[q]`g;`cv,'&`Gsqp',0`Ipt(^5,`G@rv`"
+"g^Wx$F^Iu`W)^Iq[^Iu[x]]+=(^Iq[^Iu[x]]?`G`fx^Wx$F^Iq`W^6sqq[x]^bx==q||c<2#Vv+=(v@t'`f^Iq[x]+'`Zx);c++}`4^fk,v,0)`Cwdl`7'e`G`Ar=@k,b=^g(`H,\"o^M\"),i,o,oc`5b)r=^O$y`n0;i<s.d.`Qs`8^3o=s.d.`Qs[i];oc=o."
+"`q?\"\"+o.`q:\"\"`5(oc`3$S<0||oc`3\"^woc(\")>=0)$9c`3$s<0)^g(o,\"`q\",0,s.lc);}`4r^V`Hs`0`2`5`T>3^b!^h#Ws.^n||`T#h`Fs.b^6$U^Z)s.$U^Z('`q#O);`6s.b^6b.add^Z$W)s.b.add^Z$W('click#O,false);`b^g(`H,'o^M"
+"',0,`Hl)}`Cvs`0x`2,v=s.`Y^X,g=s.`Y^X#Qk=^pvsn_'+^5+(g?@yg#i,n=^ek),e`l,y=e@S$X);e.set$Xy+10$61900:0))`5v){v*=$m`5!n`F!^fk,x,e))`40;n=x`jn%$m00>v)`40}`41`Cdyasmf`0t,m`Ft&&m&&m`3t)>=0)`41;`40`Cdyasf`"
+"0t,m`2,i=t?t`3@u:-1,n,x`5i>=0&&m){`Pn=t`10,i),x=t`1i+1)`5`cx,`G,'dyasm@Wm))`4n}`40`Cuns`0`2,x=s.`OSele`o,l=s.`OList,m=s.`OM#E,n,i;^5=^5`9`5x&&l`F!m)m=`H`M^D`5!m.toLowerCase)m`g+m;l=l`9;m=m`9;n=`cl,"
+"';`Gdyas@Wm)`5n)^5=n}i=^5`3`G`Ifun=i<0?^5:^5`10,i)`Csa`0un`2;^5#9`5!@9)@9#9;`6(`G+@9+`G)`3`G+un+`G)<0)@9+=`G+un;^5s()`Cm_i`0n,a`2,m,f=n`10,1),r,l,i`5!`Rl)`Rl`B`5!`Rnl)`Rnl`K;m=`Rl[n]`5!a&&m&&#H@Vm^"
+"a)`Ra(n)`5!m){m`B,m._c=^pm';m^an=`H`in;m^al=s^al;m^al[m^a$7m;`H`in++;m.s=s;m._n=n;$J`K('_c`G_in`G_il`G_i`G_e`G_d`G_dl`Gs`Gn`G_r`G_g`G_g1`G_t`G_t1`G_x`G_x1`G_rs`G_rr`G_l'`Im_l[$7m;`Rnl[`Rnl`8]=n}`6m"
+"._r@Vm._m){r=m._r;r._m=m;l=$J;`n0;i<l`8;i#U$2m[l[i]])r[l[i]]=m[l[i]];r^al[r^a$7r;m=`Rl[$7r`jf==f`E())s[$7m;`4m`Cm_a`7'n`Gg`Ge`G$2!g)g=^i;`Ac=s[g@l,m,x,f=0`5!c)c=`H[\"s_\"+g@l`5c&&s_d)s[g]`7\"s\",s_"
+"ft(s_d(c)));x=s[g]`5!x)x=`H[\\'s_\\'+g]`5!x)x=`H[g];m=`Ri(n,1)`5x^b!m^a||g!=^i#Vm^a=f=1`5(\"\"+x)`3\"fun`o\")>=0)x(s);`b`Rm(\"x\",n,x,e)}m=`Ri(n,1)`5@pl)@pl=@p=0;`ut();`4f'`Im_m`0t,n,d,e@X@yt;`Ps=^"
+"O,i,x,m,f=@yt,r=0,u`5`R#a`Rnl)`n0;i<`Rnl`8^3x=`Rnl[i]`5!n||x==@vm=`Ri(x);u=m[t]`5u`F@Uu)`3#C`o^y0`Fd&&e)@Zd,e);`6d)@Zd);`b@Z)}`ju)r=1;u=m[t+1]`5u@Vm[f]`F@Uu)`3#C`o^y0`Fd&&e)@1d,e);`6d)@1d);`b@1)}}m"
+"[f]=1`5u)r=1}}`4r`Cm_ll`0`2,g=`Rdl,i,o`5g)`n0;i<g`8^3o=g[i]`5o)s.^c(o.n,o.u,o.d,o.l,o.e,$8g#d0}`C^c`0n,u,d,l,e,ln`2,m=0,i,g,o=0#N,c=s.h?s.h:s.b,b,^l`5@vi=n`3':')`5i>=0){g=n`1i+$8n=n`10,i)}`bg=^i;m="
+"`Ri(n)`j(l||(n@V`Ra(n,g)))&&u^6d&&c^6$Y`V`Fd){@p=1;@pl=1`jln`F@8)u=^Fu,'@O:`G@Os:^Vi=^ps:'+s^an+':@I:'+g;b='`Ao=s.d@S`VById(@wi+'\")`5s$9`F!o.#a`H.'+g+'){o.l=1`5o.@2o.#Yo.i=0;`Ra(\"@I\",@wg+'@w(e?'"
+",@we+'\"'`f')}';f2=b+'o.c++`5!`d)`d=250`5!o.l$9.c<(`d*2)/$m)o.i=s`Xout(o.f2@7}';f1`7'e',b+'}^V^l`7's`Gc`Gi`Gu`Gf1`Gf2`G`Pe,o=0@6o=s.$Y`V(\"script\")`5o){@C=\"text/`t\"$Bid=i;o.defer=@k;o.o^M=o.onre"
+"adystatechange=f1;o.f2=f2;o.l=0;'`f'o@Q=u;c.appendChild(o)$Bc=0;o.i=s`Xout(f2@7'`f'}`eo=0}`4o^Vo=^l(s,c,i,u#N)^Qo`B;o.n=n+':'+g;o.u=u;o.d=d;o.l=l;o.e=e;g=`Rdl`5!g)g=`Rdl`K;i=0;^0i<g`8&&g[i])i++;g#d"
+"o}}`6@vm=`Ri(n);#H=1}`4m`Cvo1`0t,a`Fa[t]||$h)^O#ca[t]`Cvo2`0t,a`F#l{a#c^O[t]`5#l$h=1}`Cdlt`7'`Ad`l,i,vo,f=0`5`ul)`n0;i<`ul`8^3vo=`ul[i]`5vo`F!`Rm(\"d\")||d.g`X()-$T>=`d){`ul#d0;s.t($3}`bf=1}`j`u@2`"
+"ui`Idli=0`5f`F!`ui)`ui=s`Xout(`ut,`d)}`b`ul=0'`Idl`0vo`2,d`l`5!$3vo`B;`c^1,`G$O2',$3;$T=d.g`X()`5!`ul)`ul`K;`ul[`ul`8]=vo`5!`d)`d=250;`ut()`Ct`0vo,id`2,trk=1,tm`l,sed=Math&&@b#6?@b#D@b#6()*$m000000"
+"00000):#K`X(),$C='s'+@b#D#K`X()/10800000)%10+sed,y=tm@S$X),vt=tm@SDate($d^HMonth($d'$6y+1900:y)+' ^HHour$e:^HMinute$e:^HSecond$e ^HDay()+#f#K`XzoneO$H(),^l,^4=s.g^4(),ta`g,q`g,qs`g,#7`g,vb`B#M^1`Iu"
+"ns(`Im_ll()`5!s.td){`Ptl=^4`M,a,o,i,x`g,c`g,v`g,p`g,bw`g,bh`g,^N0',k=^f^pcc`G@k',0@0,hp`g,ct`g,pn=0,ps`5^C&&^C.prototype){^N1'`5j.m#E){^N2'`5tm.setUTCDate){^N3'`5^h^6^n&&`T#h^N4'`5pn.toPrecisio@v^N"
+"5';a`K`5a.forEach){^N6';i=0;o`B;^l`7'o`G`Pe,i=0@6i=new Iterator(o)`e}`4i^Vi=^l(o)`5i&&i.next)^N7'}}}}`j`T>=4)x=^rwidth+'x'+^r#4`5s.isns||s.^m`F`T>=3$k`p(@0`5`T>=4){c=^rpixelDepth;bw=`H#L@B;bh=`H#L^"
+"k}}$P=s.n.p^S}`6^h`F`T>=4$k`p(@0;c=^r^B`5`T#h{bw=s.d.^A`V.o$H@B;bh=s.d.^A`V.o$H^k`5!s.^n^6b){^l`7's`Gtl`G`Pe,hp=0`vh$v\");hp=s.b.isH$v(tl)?\"Y\":\"N\"`e}`4hp^Vhp=^l(s,tl);^l`7's`G`Pe,ct=0`vclientCa"
+"ps\");ct=s.b.@f`o^2`e}`4ct^Vct=^l(s$a`br`g`j$P)^0pn<$P`8&&pn<30){ps=^E$P[pn].@4@7#X`5p`3ps)<0)p+=ps;pn++}s.^d=x;s.^B=c;s.`t^t=j;s.`p=v;s.`z@H=k;s.^8@B=bw;s.^8^k=bh;s.@f`o^2=ct;s.@5=hp;s.p^S=p;s.td="
+"1`j$3{`c^1,`G$O2',vb`Ipt(^1,`G$O1',$3`js.useP^S)s.doP^S(s);`Pl=`H`M,r=^4.^A.`a`5!s.^P)s.^P=l^q?l^q:l`5!s.`a@Vs._1_`a^z`a=r;s._1_`a=1`j(vo&&$T)#W`Rm('d'#V`Rm('g')`5s.@M||^G){`Po=^G?^G:s.@M`5!o)`4'';"
+"`Pp=s.#P`r,w=1,^K,@q,x=^7t,h,l,i,oc`5^G$9==^G){^0o@Vn$x$bBODY'){o=o^9`V?o^9`V:o^9Node`5!o)`4'';^K;@q;x=^7t}oc=o.`q?''+o.`q:''`5(oc`3$S>=0$9c`3\"^woc(\")<0)||oc`3$s>=0)`4''}ta=n?o$o:1;h$5i=h`3'?^Vh="
+"s.`Q@s^C||i<0?h:h`10,#Yl=s.`Q`r;t=s.`Q^2?s.`Q^2`9:s.lt(h)`5t^bh||l))q+='&pe=@M_'+(t`Sd$c`Se'?@c(t):'o')+(h@tpev1`Zh)`f(l@tpev2`Zl):'^V`btrk=0`5s.^L@g`F!p$fs.^P;w=0}^K;i=o.sourceIndex`5@G')@x@G^Vx=1"
+";i=1`jp&&n$x)qs='&pid`Z^Ep,255))+(w@tpidt$ww`f'&oid`Z^En@7)+(x@toidt$wx`f'&ot`Zt)+(i@toi$wi#i}`j!trk@Vqs)`4'';$4=s.vs(sed)`5trk`F$4)#7=s.mr($C,(vt@tt`Zvt)`fs.hav()+q+(qs?qs:s.rq(^5)),0,id,ta);qs`g;"
+"`Rm('t')`5s.p_r)s.p_r(`I`a`g}^I(qs);^Q`u($3;`j$3`c^1,`G$O1',vb`I@M=^G=s.`Q`r=s.`Q^2=`H`m`g`5s.pg)`H^w@M=`H^weo=`H^w`Q`r=`H^w`Q^2`g`5!id@Vs.tc^ztc=1;s.flush`U()}`4#7`Ctl`0o,t,n,vo`2;s.@M=$Go`I`Q^2=t"
+";s.`Q`r=n;s.t($3}`5pg){`H^wco`0o){`P^s\"_\",1,$8`4$Go)`Cwd^wgs`0u@v`P^sun,1,$8`4s.t()`Cwd^wdc`0u@v`P^sun,$8`4s.t()}}@8=(`H`M`k`9`3'@Os^y0`Id=^A;s.b=s.d.body`5s.d@S`V#S`r^zh=s.d@S`V#S`r('HEAD')`5s.h"
+")s.h=s.h[0]}s.n=navigator;s.u=s.n.userAgent;@e=s.u`3'N$t6/^V`Papn$Z`r,v$Z^t,ie=v`3#B'),o=s.u`3'@a '),i`5v`3'@a^y0||o>0)apn='@a';^h$Q`SMicrosoft Internet Explorer'`Iisns$Q`SN$t'`I^m$Q`S@a'`I^n=(s.u`"
+"3'Mac^y0)`5o>0)`T`ws.u`1o+6));`6ie>0){`T=^Ji=v`1ie+5))`5`T>3)`T`wi)}`6@e>0)`T`ws.u`1@e+10));`b`T`wv`Iem=0`5^C#R^u){i=^o^C#R^u(256))`E(`Iem=(i`S%C4%80'?2:(i`S%U0$m'?1:0))}s.sa(un`Ivl_l='^U,`YID,vmk,"
+"`Y@T,`D,`D^j,ppu,@L,`Y`r$R,c`L,`z@F,#P`r,^P,`a,@P#0l@E^R,`G`Ivl_t=^R+',^v,$l,server,#P^2,#F`oID,purchaseID,$D,state,zip,#5,products,`Q`r,`Q^2'^W`Pn=1;n<51;n#U@D+=',prop@I,eVar@I,hier@I,list@z^R2=',"
+"tnt,pe#A1#A2#A3,^d,^B,`t^t,`p,`z@H,^8@B,^8^k,@f`o^2,@5,p^S';@D+=^R2;@o@E@D,`G`Ivl_g=@D+',`N,`N^j,`NBase,fpC`L,@R`U,#3,`Y^X,`Y^X#Q`OSele`o,`OList,`OM#E,^LDow^MLinks,^L@K,^L@g,`Q@s^C,`QDow^MFile^2s,`"
+"QEx`s,`QIn`s,`Q@iVa$n`Q@i^Zs,`Q`rs,@M,eo,_1_`a#0g@E^1,`G`Ipg=pg#M^1)`5!ss)`Hs()",
w=window,l=w.s_c_il,n=navigator,u=n.userAgent,v=n.appVersion,e=v.indexOf('MSIE '),m=u.indexOf('Netscape6/'),a,i,s;if(un){un=un.toLowerCase();if(l)for(i=0;i<l.length;i++){s=l[i];if(!s._c||s._c=='s_c'){if(s.oun==un)return s;else if(s.fs&&s.sa&&s.fs(s.oun,un)){s.sa(un);return s}}}}w.s_an='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
w.s_sp=new Function("x","d","var a=new Array,i=0,j;if(x){if(x.split)a=x.split(d);else if(!d)for(i=0;i<x.length;i++)a[a.length]=x.substring(i,i+1);else while(i>=0){j=x.indexOf(d,i);a[a.length]=x.subst"
+"ring(i,j<0?x.length:j);i=j;if(i>=0)i+=d.length}}return a");
w.s_jn=new Function("a","d","var x='',i,j=a.length;if(a&&j>0){x=a[0];if(j>1){if(a.join)x=a.join(d);else for(i=1;i<j;i++)x+=d+a[i]}}return x");
w.s_rep=new Function("x","o","n","return s_jn(s_sp(x,o),n)");
w.s_d=new Function("x","var t='`^@$#',l=s_an,l2=new Object,x2,d,b=0,k,i=x.lastIndexOf('~~'),j,v,w;if(i>0){d=x.substring(0,i);x=x.substring(i+2);l=s_sp(l,'');for(i=0;i<62;i++)l2[l[i]]=i;t=s_sp(t,'');d"
+"=s_sp(d,'~');i=0;while(i<5){v=0;if(x.indexOf(t[i])>=0) {x2=s_sp(x,t[i]);for(j=1;j<x2.length;j++){k=x2[j].substring(0,1);w=t[i]+k;if(k!=' '){v=1;w=d[b+l2[k]]}x2[j]=w+x2[j].substring(1)}}if(v)x=s_jn("
+"x2,'');else{w=t[i]+' ';if(x.indexOf(w)>=0)x=s_rep(x,w,t[i]);i++;b+=62}}}return x");
w.s_fe=new Function("c","return s_rep(s_rep(s_rep(c,'\\\\','\\\\\\\\'),'\"','\\\\\"'),\"\\n\",\"\\\\n\")");
w.s_fa=new Function("f","var s=f.indexOf('(')+1,e=f.indexOf(')'),a='',c;while(s>=0&&s<e){c=f.substring(s,s+1);if(c==',')a+='\",\"';else if((\"\\n\\r\\t \").indexOf(c)<0)a+=c;s++}return a?'\"'+a+'\"':"
+"a");
w.s_ft=new Function("c","c+='';var s,e,o,a,d,q,f,h,x;s=c.indexOf('=function(');while(s>=0){s++;d=1;q='';x=0;f=c.substring(s);a=s_fa(f);e=o=c.indexOf('{',s);e++;while(d>0){h=c.substring(e,e+1);if(q){i"
+"f(h==q&&!x)q='';if(h=='\\\\')x=x?0:1;else x=0}else{if(h=='\"'||h==\"'\")q=h;if(h=='{')d++;if(h=='}')d--}if(d>0)e++}c=c.substring(0,s)+'new Function('+(a?a+',':'')+'\"'+s_fe(c.substring(o+1,e))+'\")"
+"'+c.substring(e+1);s=c.indexOf('=function(')}return c;");
c=s_d(c);if(e>0){a=parseInt(i=v.substring(e+5));if(a>3)a=parseFloat(i)}else if(m>0)a=parseFloat(u.substring(m+10));else a=parseFloat(v);if(a>=5&&v.indexOf('Opera')<0&&u.indexOf('Opera')<0){w.s_c=new Function("un","pg","ss","var s=this;"+c);return new s_c(un,pg,ss)}else s=new Function("un","pg","ss","var s=new Object;"+s_ft(c)+";return s");return s(un,pg,ss)}
/*
 * Plugin: getQueryParam 2.1 - return query string parameter(s)
 */
s_ut.getQueryParam=new Function("p","d","u",""
+"var s=this,v='',i,t;d=d?d:'';u=u?u:(s.pageURL?s.pageURL:s.wd.locati"
+"on);if(u=='f')u=s.gtfs().location;while(p){i=p.indexOf(',');i=i<0?p"
+".length:i;t=s.p_gpv(p.substring(0,i),u+'');if(t)v+=v?d+t:t;p=p.subs"
+"tring(i==p.length?i:i+1)}return v");
s_ut.p_gpv=new Function("k","u",""
+"var s=this,v='',i=u.indexOf('?'),q;if(k&&i>-1){q=u.substring(i+1);v"
+"=s.pt(q,'&','p_gvf',k)}return v");
s_ut.p_gvf=new Function("t","k",""
+"if(t){var s=this,i=t.indexOf('='),p=i<0?t:t.substring(0,i),v=i<0?'T"
+"rue':t.substring(i+1);if(p.toLowerCase()==k.toLowerCase())return s."
+"epa(v)}return ''");

/*BEGIN TRACKING CODE */
/* SiteCatalyst Variables */
s_ut.prop29=GCION.Cookies.Cookie.Get('zagSession');
s_ut.prop14='';
s_ut.prop25='usat';
s_ut.prop48=GCION.Cookies.Cookie.Get('rsi_seg');
s_ut.prop50='usatoday';
//s_ut.eVar8='';
//s_ut.eVar9='';
s_ut.eVar10='';
s_ut.eVar12='';

if (GCION.Cookies.Cookie.Get('USATINFO')){
	var strUsatOmni = GCION.Cookies.Cookie.Get('USATINFO');
	var arrUSATICookie = strUsatOmni.split('&');
	for (var USATIIndex=0;USATIIndex<arrUSATICookie.length;USATIIndex++){
		if (arrUSATICookie[USATIIndex].indexOf('Status=') > -1){ //array object contains 'Status'
				arrCookie = arrUSATICookie[USATIIndex].split("=");
				arrCookie = unescape(arrCookie[1]);
				s_ut.eVar21 = arrCookie;
		} //if
	} // for
} else {
	s_ut.prop29 = '';
} //if

/*
function decConvertFromBase(num, base)
{
	var decNum=0;
	var power=0;
	// loop backward
	for (i=num.length-1; i>=0; i--)
	{
		var digit=num.charAt(i);
		if (digit>='a' || digit>='A')
		{
			if (digit=='a' || digit=='A')
				digit=10;
			else if (digit=='b' || digit=='B')
				digit=11;
			else if (digit=='c' || digit=='C')
				digit=12;
			else if (digit=='d' || digit=='D')
				digit=13;
			else if (digit=='e' || digit=='E')
				digit=14;
			else if (digit=='f' || digit=='F')
				digit=15;
		}
		decNum+=digit*Math.pow(base, power);
		power++;
	}
	return decNum;
}*/

var zagGen, zagYob, zagAge, zagAgeLow, zagAgeHigh, zagCou1, zagCou2, zagZip, zagAgeLow, zagAgeHigh, zagIncLow, zagIncHigh;

if (GCION.Cookies.Cookie.Get('zagCookie')){
	var objUsatZag = GCION.Sites.USAT.ZagitoObj();

	zagGen= objUsatZag.fem;
	zagCou1= objUsatZag.cou;
	zagZip= objUsatZag.zip;
	zagYob= objUsatZag.yob;
	var year=new Date();
	year=year.getYear();
	zagAge=year-zagYob;	

if (zagGen== 0){zagGen='Male'}
if (zagGen== 1) {zagGen='Female'}
else {zagGEN='~'}

s_ut.prop32= zagGen;
s_ut.prop35= zagCou1;
s_ut.prop30= zagZip;

if (zagAge >= 0 && zagAge <= 5) {zagAgeLow=0; zagAgeHigh=5}
if (zagAge >= 6 && zagAge <= 10) {zagAgeLow=5; zagAgeHigh=10}
if (zagAge >= 11 && zagAge <= 15) {zagAgeLow=10; zagAgeHigh=15}
if (zagAge >= 16 && zagAge <= 20) {zagAgeLow=15; zagAgeHigh=20}
if (zagAge >= 21 && zagAge <= 25) {zagAgeLow=20; zagAgeHigh=25}
if (zagAge >= 26 && zagAge <= 30) {zagAgeLow=25; zagAgeHigh=30}
if (zagAge >= 31 && zagAge <= 35) {zagAgeLow=30; zagAgeHigh=35}
if (zagAge >= 36 && zagAge <= 40) {zagAgeLow=35; zagAgeHigh=40}
if (zagAge >= 41 && zagAge <= 45) {zagAgeLow=40; zagAgeHigh=45}
if (zagAge >= 46 && zagAge <= 50) {zagAgeLow=45; zagAgeHigh=50}
if (zagAge >= 51 && zagAge <= 55) {zagAgeLow=50; zagAgeHigh=55}
if (zagAge >= 56 && zagAge <= 60) {zagAgeLow=55; zagAgeHigh=60}
if (zagAge >= 61 && zagAge <= 65) {zagAgeLow=60; zagAgeHigh=65}
if (zagAge >= 66 && zagAge <= 150) {zagAgeLow=65; zagAgeHigh=150}

s_ut.eVar16= zagAgeLow + '-' + zagAgeHigh;


/*
function ParseZago(zagCookie) {
  zagCookie+=""
  var u= "undefined";
  var r= {siz:u, gci:u, cou:u, sit:u, yob:u, ind:u, job:u};
  r.version= parseInt(zagCookie);
  if (isNaN(r.version)) {r.version= 2; return r;}
  var nvps= zagCookie.split('n');
  for (var j= 0; j < nvps.length; j++) {
    var nv= nvps[j].split('v');
    if (2 == nv.length) {
      var nam= zDecodeName(nv[0]);
      var val= {cou: 1, gci: 1, sit: 1}[nam] ?zDecodeName(nv[1]) :parseInt(nv[1], 16);
      r[nam]= val;
    }
  }
  return r;
}

function zDecodeName (name) {
  var r= '';
  for (var j= 0; j <name.length; j+=2)
    r+= String.fromCharCode(parseInt(name.substring(j, j+2), 16));
  return r;
}*/

var jobLookup= {
    1: 'Chairman',
    2: 'CFO',
    3: 'VP',
    4: 'Director',
    5: 'Other Management Level Title',
    6: 'Self-employed',
    7: 'Salaried Professional',
    8: 'Hourly employee',
    9: 'Student',
    10: 'Retired',
    11: 'Not Employed',
    12: 'Other',
    undefined:'undefined'
}

var indLookup= {
    1: 'Accounting',
	39: 'Aerospace/Defense',
	2: 'Agriculture/Mining',
	3: 'Architecture/Design',
	4: 'Arts/Entertainment',
	38: 'Automotive',
	5: 'Computers/Software/Technology',
	6: 'Construction',
	7: 'Consulting',
	8: 'Education/Schools/Academia',
	9: 'Energy/Utilities/Fuel/Chemicals',
	10: 'Engineering',
	11: 'Finance/Banking/Brokerage',
	12: 'Government/Diplomatic services',
	13: 'Health Care/Hospitals',
	34: 'Homemaker',
	14: 'Import/Export/Trade',
	15: 'Information Management/Library',
	16: 'Insurance',
	17: 'Legal',
	18: 'Manufacturing',
	19: 'Marketing/Advertising/Communications/PR',
	20: 'Media/Publishing/Broadcasting',
	21: 'Military',
	22: 'Non-profit/Associations',
	37: 'Other',
	23: 'Pharmaceuticals/Biotech',
	24: 'Real Estate/Property Management',
	25: 'Recruiting/Staffing/Human Resources',
	26: 'Religious Institutions',
	27: 'Research &amp; Development/Research',
	28: 'Retail',
	36: 'Retired',
	29: 'Social Services',
	35: 'Student',
	30: 'Telecommunications',
	31: 'Transportation/Logistics',
	32: 'Travel/Hospitality/Service',
	33: 'Wholesale',
	undefined:'undefined'
}

var zag = objUsatZag;
s_ut.prop27=zag.gci;
zag.version= parseInt(GCION.Cookies.Cookie.Get('zagCookie'));
if (zag.version== 0) {zag.version='0'}
s_ut.prop28=zag.version;
s_ut.prop31=zag.yob;
s_ut.prop33=jobLookup[''+zag.job];
s_ut.prop34=indLookup[''+zag.ind];
s_ut.prop37=zag.sit;
if (zag.siz== 0) {zag.siz='0-99'}
s_ut.prop39=zag.siz;

var zagged=zag.version
if (zagged== 0){zagged='false'}
else if (zagged== 1){zagged='true'}
else if (zagged== 2) {zagged='false'}
else if (zagged== 3) {zagged='true'}
else {zagged='false'}
s_ut.prop38=zagged;
s_ut.eVar15=s_ut.prop32;
s_ut.eVar17=s_ut.prop35;
s_ut.eVar18=s_ut.prop30;

}

var usatsstsLoc ='';
var usattempReq = s_ut.getQueryParam('req');
var usattempTopic = s_ut.getQueryParam('tag');
if(usattempReq){var usattempLoc = new Array();
usattempLoc = usattempTopic.replace('%5e', '^').split('^');
usatsstsLoc = usattempReq+': /' +usattempLoc.reverse().join('/');
s_ut.prop42=usatsstsLoc;
}


/*** COMSCORE 360 INFO ********/

document.write(unescape('%3Cscript type="text/javascript" src="' + (document.location.protocol == 'https:' ? 'https://sb' : 'http://b') + '.scorecardresearch.com/beacon.js" %3E%3C/script%3E'));
document.write(unescape('%3Cscript type="text/javascript" src="http://i.usatoday.net/_common/_scripts/_omniture/comscore.js" %3E%3C/script%3E'));


/*** ContextWeb contextual tracking - forecast ***/

document.write(unescape('%3Cscript type="text/javascript" src="' +
   'http://atd.agencytradingdesk.net/WatsonTracker/IMP/A1000138/C1000187/P1003017/cw.jsx?t=1' +
   '" %3E%3C/script%3E'));


/************* DO NOT ALTER ANYTHING BELOW THIS LINE ! **************/
var s_code=s_ut.t();if(s_code)document.write(s_code);

//if a quick load page, dont make revsci calls
if (!window.usat_analytics_fast_url) {
document.write('<scr'+'ipt type="text/javascript" src="http://js.revsci.net/gateway/gw.js?csid=J06575" CHARSET="ISO-8859-1"></s'+'cript>');
document.write('<scr'+'ipt type="text/javascript" src="http://i.usatoday.net/_common/_scripts/_revsci/populate.js"></s'+'cript>');	
}



